/*******************************************************************************

Title: 			04_anthro_cleaning_health_paper.do
Author(s): 		Caleb Jeremie Dohou & Luca Stanus Ghib
Description: 	This dofile loads the raw data with corrections applied and deidentifies it.
Input: 	"${raw_deid}", see global defined in Project_MasterDofile.do
Output:	"${clean}", see global defined in Project_MasterDofile.do

*******************************************************************************/

******** load raw dataset
use "${hp_anthro_raw_deid}", clear

*** Drop non-consented observations
drop if consent == 0

** * drop HHs with no eligible children for anthro (can also not do it since missing height/weight won't count towards result, but good to be intentional and have the right sample size on hand at all times)
drop if eligible_yn == . | eligible_yn == 0

// there are a few cases in which a child was selected but no child was measured 
drop if height == . & weight == .

* rename start measurement var bc it has typo
rename start_measrues start_measures


// format start_measures as Stata date (needed to compute difference between time of measurement and date of birth to get age in days, needed for igrowup_ado)
rename 		start_measures start_measures_str
generate 	start_measures = dofc(clock(start_measures_str, "YMDhms")) // clock transforms it into Stata date, dofc truncates to just date without time (not needed in our case)
format 		start_measures %td

*** destring village variable
destring village, replace


******** save clean dataset ready for variable construction
save "${hp_anthro_clean}", replace




* end of dofile *
