/*******************************************************************************

Title: 			figure_2_health_paper.do
Author(s): 		Luca Stanus Ghib & Caleb Jeremie Dohou
Description: 	This dofile produces output.
Input: 	"${hp_anthro_z_constructed}", see global defined in Project_MasterDofile.do
Output:	"${hp_graphs}"

*******************************************************************************/

******** load raw dataset
use "${hp_anthro_z_constructed}", clear

******* Graph with T vs C k-densities for Lancet paper
*** DIME Wiki template (https://worldbank.github.io/stata-visual-library/density-av.html)

/**********************************************************************************
               FIGURE: kernel density graph with mean marker
**********************************************************************************/

*** Prepare example/trial graph only for lenght-for-age for now, i.e. _zlen
* trial to mimick Luby et al graphs: my hunch is that they just drop observations lower than -5 and higher than +2 from the graph, and this way it looks centered at the control/treated means rather than at 0, just because the bulk of the observations is between -4 and +1. It's too neat to be done via X SDs or IQR or stuff like that to drop outliers. Can also use winsorised 1st and 99th percentiles.
*winsor2 _zlen _zwei _zwfl, replace // default command: winsorised at 1st and 99th percentiles (not trimmed!)

* Loop to produce anthro graphs

local anthro_vars _zlen_winsor _zwei_winsor _zwfl_winsor

foreach var of varlist `anthro_vars' {
	* Calculate means
	sum     `var' if treatment_status == 0 // C mean
	local   control_mean = r(mean)
	sum     `var' if treatment_status == 1 // T mean
	local   treatment_mean = r(mean)
	
	local varlab: variable label `var'
	
	* Plot
	twoway  (kdensity `var' if treatment_status == 0, color(gs10)) ///
			(kdensity `var' if treatment_status == 1, color(emerald)) ///
			, ///
			xline(`control_mean', lcolor(gs12) lpattern(solid)) ///
            xline(`treatment_mean', lcolor(eltgreen) lpattern(dash)) ///
            legend(order(1 "Control" 2 "Intervention" 3 "Control mean (solid vertical)" 4 "Intervention mean (dash vertical)") size(small)) ///
            xtitle(`varlab') ///
            ytitle(Density) ///
            bgcolor (white) graphregion(color(white))
	
	local var = plural(2, "`var'", "-_winsor")
			
	* Export
	*graph export "${output_hp}/`var'_k-density.png", replace
	graph export "${hp_graphs}/`var'_k-density.tif", replace
	*graph export "${output_hp}/`var'_k-density.eps", replace
} 		

* end of dofile *
