/*******************************************************************************

Title: 			04_cleaning.do
Author(s): 		Luca Stanus Ghib
Description: 	This dofile loads the raw data with corrections applied and deidentifies it.
Input: 	"${raw_deid}", see global defined in Project_MasterDofile.do
Output:	"${clean}", see global defined in Project_MasterDofile.do

*******************************************************************************/

******** load raw dataset
use "${hp_hh_raw_deid}", clear

******** cleaning section

// destring vars that are wrongly strings (takes a couple of minutes to run)
destring village och_age_years_calc_* nch_age_years_calc_* och_age_years_calc2_* nch_age_years_calc2_* och_missedsch_why_1_* och_missedsch_why_2_* och_missedsch_why_3_* och_missedsch_why_4_* och_missedsch_why_5_* och_missedsch_why_6_* och_missedsch_why_7_* och_missedsch_why__555_* nch_missedsch_why_1_* nch_missedsch_why_2_* nch_missedsch_why_3_* nch_missedsch_why_4_* nch_missedsch_why_5_* nch_missedsch_why_6_* nch_missedsch_why_7_* nch_missedsch_why__555_* room_roof room_wall room_floor religion mother_tongue marital_status resp_educ midl_children_roster_count endl_children_roster_count, replace


***** check latrine (defec_facility_hh) & water point (main_drink_source) typology to construct secondary outcomes improved water source & improved latrine
// main_drink_source already correctly coded as categorical variables and ready for analysis, 132 missing values

// defec_facility_hh correctly coded as categorical variable, 135 missing values

tabulate defec_facility_hh, mi

tabulate defec_facility_hh, mi nol


replace defec_facility_hh = 12 if defec_facility_hh_oth == "LA TOILLETE A ETE EMPORTE PARR LA PLUIE DONC PAS DE TOILLETE DANS CE MENAGE" | /// 
								  defec_facility_hh_oth == "PAS DE TOILLETTE IL SE DEBROUILLE ET PARFOIS CHEZ LE VOISIN OU DANS LA BROUSSE" | ///   
								  defec_facility_hh_oth == "N’EXISTE PAS" | /// 
								  defec_facility_hh_oth == "Enbrouse" | /// 
								  defec_facility_hh_oth == "PAS DE TOILETE" | /// 
								  defec_facility_hh_oth == "Pas d’i’nstallation hygienique" | /// 
								  defec_facility_hh_oth == "AUCUNE  TOILETTE" | /// 
								  defec_facility_hh_oth == "PAS D’ INSTALLATION" | /// 
								  defec_facility_hh_oth == "LATRINES EN CONSTRUCTION" | /// 
								  defec_facility_hh_oth == "LACTRINE EN CONSTRUCTION" | /// 
								  defec_facility_hh_oth == "A L'AIR LIBRE" | /// 
								  defec_facility_hh_oth == "LATRINE  DETRUITE PAR LA PLUIE" | /// 
								  defec_facility_hh_oth == "PAS D’ INSTALLATION  MAIS EST ENTRAIN DE CONSTRUIRE" | ///
								  defec_facility_hh_oth == "Pas des toilettes" | /// 
								  defec_facility_hh_oth == "PAS DE TOILETTE" | /// 
								  defec_facility_hh_oth == "PAS DE TOILETTE POUR LE MOMENT" | ///
								  defec_facility_hh_oth == "DANS LA BROUSSE OU CHEZ LE VOISIN" | ///
								  defec_facility_hh_oth == "DERRIERE LA MAISON" | ///
								  defec_facility_hh_oth == "LATRINE DETRUITE" | ///
								  defec_facility_hh_oth == "Pas de toilette" | ///
								  defec_facility_hh_oth == "pas de  toilette" | ///
								  defec_facility_hh_oth == "PAS DE LACTRINE" | ///
								  defec_facility_hh_oth == "PAS DE TOILETTE" | ///
								  defec_facility_hh_oth == "LE MÉNAGE AVAIT UNE TOILETTE MAIS,ELLE S’EST ÉCROULÉE LORS DE LA PLUIE" | ///
								  defec_facility_hh_oth == "DANS UN PETIT COIN" | ///
								  defec_facility_hh_oth == "L INSTALLATION EN COURS DE CONSTRUCTION" | /// 
								  defec_facility_hh_oth == "LE MENAGE POSSEDAIT LE LATRINE AVEC DALLE,MAIS PENDANT NOTRE PASSAGE ,ON AVONS TROUVE QUE LE LATRINE PAR TERRE FAUTE DE GRANDE PLUIE.DONC PRESENTEMENT LE MENAGE EST EN PLEIN RECONSTRUCTION" 
						

replace defec_facility_hh_oth = "" if defec_facility_hh_oth == "LA TOILLETE A ETE EMPORTE PARR LA PLUIE DONC PAS DE TOILLETE DANS CE MENAGE" | /// 
								  defec_facility_hh_oth == "PAS DE TOILLETTE IL SE DEBROUILLE ET PARFOIS CHEZ LE VOISIN OU DANS LA BROUSSE" | ///   
								  defec_facility_hh_oth == "N’EXISTE PAS" | /// 
								  defec_facility_hh_oth == "Enbrouse" | /// 
								  defec_facility_hh_oth == "PAS DE TOILETE" | /// 
								  defec_facility_hh_oth == "Pas d’i’nstallation hygienique" | /// 
								  defec_facility_hh_oth == "AUCUNE  TOILETTE" | /// 
								  defec_facility_hh_oth == "PAS D’ INSTALLATION" | /// 
								  defec_facility_hh_oth == "LATRINES EN CONSTRUCTION" | /// 
								  defec_facility_hh_oth == "LACTRINE EN CONSTRUCTION" | /// 
								  defec_facility_hh_oth == "A L'AIR LIBRE" | /// 
								  defec_facility_hh_oth == "LATRINE  DETRUITE PAR LA PLUIE" | /// 
								  defec_facility_hh_oth == "PAS D’ INSTALLATION  MAIS EST ENTRAIN DE CONSTRUIRE" | ///
								  defec_facility_hh_oth == "Pas des toilettes" | /// 
								  defec_facility_hh_oth == "PAS DE TOILETTE" | /// 
								  defec_facility_hh_oth == "PAS DE TOILETTE POUR LE MOMENT" | ///
								  defec_facility_hh_oth == "DANS LA BROUSSE OU CHEZ LE VOISIN" | ///
								  defec_facility_hh_oth == "DERRIERE LA MAISON" | ///
								  defec_facility_hh_oth == "LATRINE DETRUITE" | ///
								  defec_facility_hh_oth == "Pas de toilette" | ///
								  defec_facility_hh_oth == "pas de  toilette" | ///
								  defec_facility_hh_oth == "PAS DE LACTRINE" | ///
								  defec_facility_hh_oth == "PAS DE TOILETTE" | ///
								  defec_facility_hh_oth == "LE MÉNAGE AVAIT UNE TOILETTE MAIS,ELLE S’EST ÉCROULÉE LORS DE LA PLUIE" | ///
								  defec_facility_hh_oth == "DANS UN PETIT COIN" | ///
								  defec_facility_hh_oth == "L INSTALLATION EN COURS DE CONSTRUCTION" | /// 
								  defec_facility_hh_oth == "LE MENAGE POSSEDAIT LE LATRINE AVEC DALLE,MAIS PENDANT NOTRE PASSAGE ,ON AVONS TROUVE QUE LE LATRINE PAR TERRE FAUTE DE GRANDE PLUIE.DONC PRESENTEMENT LE MENAGE EST EN PLEIN RECONSTRUCTION" 
								  
								  
								  
replace defec_facility_hh = 8 if defec_facility_hh_oth == "LATRINE A COMPOSTE CHEZ LE VOISIN"

replace defec_facility_hh_oth = "" if defec_facility_hh_oth == "LATRINE A COMPOSTE CHEZ LE VOISIN"
								  
								  
replace defec_facility_hh = 9 if defec_facility_hh_oth == "DANS UN PETIT TROU NON COUVERT" | /// 
								 defec_facility_hh_oth == "CHEZ LE VOISIN DANS UN TROU" | /// 
								 defec_facility_hh_oth == "LATRINE EN PLANCHE BIEN COUVERTE" | /// 
								 defec_facility_hh_oth == "LATRINES A FOSSE COUVERTES PAR DES PLANCHETTES AU-DESSUS" | /// 
								 defec_facility_hh_oth == "UNE PETITE PIECE EN FEUILLE DE BANANE" | /// 
								 defec_facility_hh_oth == "PETIT MAISON EN FEUILLE"
		
		
replace defec_facility_hh_oth = "" if defec_facility_hh_oth == "DANS UN PETIT TROU NON COUVERT" | /// 
								 defec_facility_hh_oth == "CHEZ LE VOISIN DANS UN TROU" | /// 
								 defec_facility_hh_oth == "LATRINE EN PLANCHE BIEN COUVERTE" | /// 
								 defec_facility_hh_oth == "LATRINES A FOSSE COUVERTES PAR DES PLANCHETTES AU-DESSUS" | /// 
								 defec_facility_hh_oth == "UNE PETITE PIECE EN FEUILLE DE BANANE" | /// 
								 defec_facility_hh_oth == "PETIT MAISON EN FEUILLE"

** Note: There are 67 other specify cases that could not be reassigned because they are not much informative. They refer to HH members going to neigbor's facility for defecation. For the analysis, they may be relocated to unimproved defecation facility since the houshold does not have a latrine.

**** Variables for water governance perception (HH-level)
/* Water governance perception index (fairness of selection of water governance entity, perception of fair treatment, confidence in managing money, confidence in response to breakdowns, confidence in management, overall satisfaction).
- fairness of selection of water governance entity = comm_select_fairly (need to recode -999 to .d)
- perception of fair treatment = fairtreat_bycomm (need to recode -999 to .d and -888 to .r)
- confidence in managing money = comm_money_manage (need to recode -999 to .d and -888 to .r)
- confidence in response to breakdowns = comm_response_breakd (need to recode -999 to .d and -888 to .r)
- confidence in management = trust_comm_response (need to recode -999 to .d and -888 to .r)
- overall satisfaction = satisfac_water_access (need to recode -999 to .d and -888 to .r)
*/
 
local gov_perception comm_select_fairly fairtreat_bycomm comm_money_manage comm_response_breakd trust_comm_response satisfac_water_access

foreach var of local gov_perception { // local doesn't need to be called with `' when used with foreach otherwise it's unrecognised!
	recode `var' (-999 = .d) (-888 = .r)
}


**** Change name of school attendance in past week variable for new children so that it matches the stub used in the old children module (they're the same outcome variable) and it can be easily dealt with & made a unique outcome when reshaping the old & new children rosters in 05_construct
forvalues i = 1/6 {
	rename nch_school_attend_`i' nch_attendsch_lwks_`i'
}

**** Variables for structured observations ****

*tab so_consent, mi
tab so_consent consent, mi


*tab so_moment_obs, mi
tab so_any_event, mi

tab so_consent so_any_event, mi


tab so_event_1, mi

tab so_who_event_1, mi
tab so_wash_hands_1, mi

tab so_hw_material_1, mi
tab so_hw_material_1, mi nol
recode so_hw_material_* (-777 = .n)



tab so_hw_material_1 so_wash_hands_1, mi


******** School attendance  variables ******

replace och_missedsch_why_3 = subinstr(och_missedsch_why_3, "-555", "4", .) if och_missedsch_why_oth_3 == "Il ne pouvait pas aller à l'école pour toute la famille avait passé toute une semaine au champ"
			
replace och_missedsch_why_5_3 = 1 if och_missedsch_why_oth_3 == "Il ne pouvait pas aller à l'école pour toute la famille avait passé toute une semaine au champ"    
			
replace och_missedsch_why__555_3 = 0 if och_missedsch_why_oth_3 == "Il ne pouvait pas aller à l'école pour toute la famille avait passé toute une semaine au champ"
		  
replace och_missedsch_why_oth_3 = "" if och_missedsch_why_oth_3 == "Il ne pouvait pas aller à l'école pour toute la famille avait passé toute une semaine au champ"


forvalues i=1/23{

replace och_missedsch_why_`i' = subinstr(och_missedsch_why_`i', "-555", "4", .) /// 
                            if och_missedsch_why_oth_`i' == "CONGE DE NOËL" | /// 
                               och_missedsch_why_oth_`i' == "CONGE DE NOEL" | /// 
                        och_missedsch_why_oth_`i' == "FETE DE NOUVELLE ANS" | /// 
            och_missedsch_why_oth_`i' == "EN VACANCES DE NOEL ET NOUVEL AN" | /// 
			och_missedsch_why_oth_`i' == "ILS ÉTAIENT EN CONGÉ, MAINTENANT ELLE DOIT REJOINDRE SON LE LIEUX DE SON ÉCOLE À DOMIONGO  DEMAIN MATIN"																 | /// 
		    och_missedsch_why_oth_`i' == "MÊME CHOSE AUSSI AVEC SES SOEURS, IL DOIT SE RENDRE À DOMIONGO DEMAIN POUR SES ÉTUDES,  ILS ÉTAIENT EN VACANCES"													  | /// 
		och_missedsch_why_oth_`i' == "Il y avait la vacance de fin d'année"
			
   
replace och_missedsch_why_4_`i' = 1 if och_missedsch_why_oth_`i' == "CONGE DE NOËL" | /// 
                                     och_missedsch_why_oth_`i' == "CONGE DE NOEL"   | /// 
                              och_missedsch_why_oth_`i' == "FETE DE NOUVELLE ANS"   | /// 
                  och_missedsch_why_oth_`i' == "EN VACANCES DE NOEL ET NOUVEL AN"   | /// 
			och_missedsch_why_oth_`i' == "ILS ÉTAIENT EN CONGÉ, MAINTENANT ELLE DOIT REJOINDRE SON LE LIEUX DE SON ÉCOLE À DOMIONGO  DEMAIN MATIN"																         | /// 
		    och_missedsch_why_oth_`i' == "MÊME CHOSE AUSSI AVEC SES SOEURS, IL DOIT SE RENDRE À DOMIONGO DEMAIN POUR SES ÉTUDES,  ILS ÉTAIENT EN VACANCES"													          | /// 
		och_missedsch_why_oth_`i' == "Il y avait la vacance de fin d'année"   
			
replace och_missedsch_why__555_`i' = 0 if och_missedsch_why_oth_`i' == "CONGE DE NOËL" | /// 
                                        och_missedsch_why_oth_`i' == "CONGE DE NOEL"   | /// 
                                 och_missedsch_why_oth_`i' == "FETE DE NOUVELLE ANS"   | /// 
                  och_missedsch_why_oth_`i' == "EN VACANCES DE NOEL ET NOUVEL AN"      | /// 
			och_missedsch_why_oth_`i' == "ILS ÉTAIENT EN CONGÉ, MAINTENANT ELLE DOIT REJOINDRE SON LE LIEUX DE SON ÉCOLE À DOMIONGO  DEMAIN MATIN"																 | /// 
		    och_missedsch_why_oth_`i' == "MÊME CHOSE AUSSI AVEC SES SOEURS, IL DOIT SE RENDRE À DOMIONGO DEMAIN POUR SES ÉTUDES,  ILS ÉTAIENT EN VACANCES"													  | /// 
		och_missedsch_why_oth_`i' == "Il y avait la vacance de fin d'année"
				  
replace och_missedsch_why_oth_`i' = "" if och_missedsch_why_oth_`i' == "CONGE DE NOËL" | /// 
                                        och_missedsch_why_oth_`i' == "CONGE DE NOEL" | /// 
                                 och_missedsch_why_oth_`i' == "FETE DE NOUVELLE ANS" | /// 
                  och_missedsch_why_oth_`i' == "EN VACANCES DE NOEL ET NOUVEL AN" | /// 
			och_missedsch_why_oth_`i' == "ILS ÉTAIENT EN CONGÉ, MAINTENANT ELLE DOIT REJOINDRE SON LE LIEUX DE SON ÉCOLE À DOMIONGO  DEMAIN MATIN"																 | /// 
		    och_missedsch_why_oth_`i' == "MÊME CHOSE AUSSI AVEC SES SOEURS, IL DOIT SE RENDRE À DOMIONGO DEMAIN POUR SES ÉTUDES,  ILS ÉTAIENT EN VACANCES"													  | /// 
		och_missedsch_why_oth_`i' == "Il y avait la vacance de fin d'année"
				  
list och_schooling_`i' och_attendsch_lwks_`i' och_missedsch_why_oth_`i' if och_missedsch_why_oth_`i' != ""

}			  
				  
** Create answer choice 8 referring to Teacher's strike

forvalues i=1/23{
gen och_missedsch_why_8_`i' =.
}

forvalues i=1/23{
replace och_missedsch_why_`i' = subinstr(och_missedsch_why_`i', "-555", "8", .) /// 
                     if och_missedsch_why_oth_`i' == "GREVE DES ENSEIGNATS" | /// 
                                       och_missedsch_why_oth_`i' == "GREVE" | /// 
                       och_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE." | /// 
					  och_missedsch_why_oth_`i' == "ENSEIGNANTS  EN GRÈVE." | /// 
					   och_missedsch_why_oth_`i' == "GREVE DES ENSEIGNANTS" | ///  
					    och_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE" | /// 
						            och_missedsch_why_oth_`i' == "ET GREVE"
						

replace och_missedsch_why_8_`i' = 1 if och_missedsch_why_oth_`i' == "GREVE DES ENSEIGNATS" | /// 
                                                      och_missedsch_why_oth_`i' == "GREVE" | /// 
                                    och_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE."   | /// 
									 och_missedsch_why_oth_`i' == "ENSEIGNANTS  EN GRÈVE." | /// 
					                  och_missedsch_why_oth_`i' == "GREVE DES ENSEIGNANTS" | ///  
					                   och_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE" | /// 
						                           och_missedsch_why_oth_`i' == "ET GREVE" 
									
replace och_missedsch_why__555_`i' = 0 if och_missedsch_why_oth_`i' == "GREVE DES ENSEIGNATS" | /// 
                                                         och_missedsch_why_oth_`i' == "GREVE" | /// 
                                       och_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE."   | /// 
									    och_missedsch_why_oth_`i' == "ENSEIGNANTS  EN GRÈVE." | /// 
					                     och_missedsch_why_oth_`i' == "GREVE DES ENSEIGNANTS" | ///  
					                      och_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE" | /// 
						                              och_missedsch_why_oth_`i' == "ET GREVE"
									
replace och_missedsch_why_oth_`i' = "" if och_missedsch_why_oth_`i' == "GREVE DES ENSEIGNATS" | /// 
                                                         och_missedsch_why_oth_`i' == "GREVE" | /// 
                                       och_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE."   | /// 
									    och_missedsch_why_oth_`i' == "ENSEIGNANTS  EN GRÈVE." | /// 
					                     och_missedsch_why_oth_`i' == "GREVE DES ENSEIGNANTS" | ///  
					                      och_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE" | /// 
						                              och_missedsch_why_oth_`i' == "ET GREVE"
									   
list och_schooling_`i' och_attendsch_lwks_`i' och_missedsch_why_oth_`i' if och_missedsch_why_oth_`i' != ""

}


 **** Child is not schooling (Turn all related variables to missing and och_schooling_1 to 0)
replace och_missedsch_why_1 = subinstr(och_missedsch_why_1, "-555", "", .) if och_missedsch_why_oth_1 == "Elle a déjà fini les études"
replace och_missedsch_why__555_1 = . if och_missedsch_why_oth_1 == "Elle a déjà fini les études"
replace och_attendsch_lwks_1 = . if och_missedsch_why_oth_1 == "Elle a déjà fini les études"
replace och_schooling_1 = 0 if och_missedsch_why_oth_1 == "Elle a déjà fini les études"
replace och_missedsch_why_oth_1 = "" if och_missedsch_why_oth_1 == "Elle a déjà fini les études"

**** Respondent does not know if child went to school the past week or not (missing code in nch_attendsch_lwks: .d)


** "L' ENFANT N EST PAS SUR PLE IL EST À ILEBO, ELLE NE SAIT PLUS" has a character that cnnot be found. Using the survey ID for the correction resolves the issue.

replace och_missedsch_why_1 = subinstr(och_missedsch_why_1, "-555", "", .) if survey_hh_id == "HH21281101" 
replace och_missedsch_why__555_1 = . if survey_hh_id == "HH21281101"										  
replace och_attendsch_lwks_1 = .d if survey_hh_id == "HH21281101"										  
replace och_missedsch_why_oth_1 = "" if survey_hh_id == "HH21281101"


** "IL N 'EST PAS ICI IL EST À ILEBO" has a character that cnnot be found. Using the survey ID for the correction resolves the issue.
replace och_missedsch_why_5 = subinstr(och_missedsch_why_5, "-555", "", .) if survey_hh_id == "HH21131001" 
replace och_missedsch_why__555_5 = . if survey_hh_id == "HH21131001"										  
replace och_attendsch_lwks_5 = .d if survey_hh_id == "HH21131001"										  
replace och_missedsch_why_oth_5 = "" if survey_hh_id == "HH21131001"

 
  forvalues i=1/23{
replace och_missedsch_why_`i' = subinstr(och_missedsch_why_`i', "-555", "", .) if /// 
                                              och_missedsch_why_oth_`i' == "SUR UNE AUTRE VILLE" | /// 
	                                                  och_missedsch_why_oth_`i' == "Ne sait pas" | /// 
	                 och_missedsch_why_oth_`i' == "POUR LE MOMENT IL FAIT SES ÉTUDES À KINSHASA" | /// 
	                                             och_missedsch_why_oth_`i' == "IL EST À KANANGA" | /// 
	                             och_missedsch_why_oth_`i' == "IL N 'EST PAS ICI IL EST À ILEBO" | /// 
	                              och_missedsch_why_oth_`i' == "Elle et lui ailleurs à  Kananga" | /// 
	                                          och_missedsch_why_oth_`i' == "Il EST À LUBUMBASHI" | /// 
											      och_missedsch_why_oth_`i' == "POUR LES ÉTUDES" | /// 
												      och_missedsch_why_oth_`i' == "Ne sais pas"
												  

replace och_missedsch_why__555_`i' = . if och_missedsch_why_oth_`i' == "SUR UNE AUTRE VILLE" | ///   
	                                                  och_missedsch_why_oth_`i' == "Ne sait pas" | /// 
	                 och_missedsch_why_oth_`i' == "POUR LE MOMENT IL FAIT SES ÉTUDES À KINSHASA" | /// 
	                                             och_missedsch_why_oth_`i' == "IL EST À KANANGA" | /// 
	                             och_missedsch_why_oth_`i' == "IL N 'EST PAS ICI IL EST À ILEBO" | /// 
	                              och_missedsch_why_oth_`i' == "Elle et lui ailleurs à  Kananga" | /// 
	                                          och_missedsch_why_oth_`i' == "Il EST À LUBUMBASHI" | /// 
											      och_missedsch_why_oth_`i' == "POUR LES ÉTUDES" | /// 
												      och_missedsch_why_oth_`i' == "Ne sais pas"
										  
replace och_attendsch_lwks_`i' = .d if och_missedsch_why_oth_`i' == "SUR UNE AUTRE VILLE" | ///   
	                                                  och_missedsch_why_oth_`i' == "Ne sait pas" | /// 
	                 och_missedsch_why_oth_`i' == "POUR LE MOMENT IL FAIT SES ÉTUDES À KINSHASA" | /// 
	                                             och_missedsch_why_oth_`i' == "IL EST À KANANGA" | /// 
	                             och_missedsch_why_oth_`i' == "IL N 'EST PAS ICI IL EST À ILEBO" | /// 
	                              och_missedsch_why_oth_`i' == "Elle et lui ailleurs à  Kananga" | /// 
	                                          och_missedsch_why_oth_`i' == "Il EST À LUBUMBASHI" | /// 
											      och_missedsch_why_oth_`i' == "POUR LES ÉTUDES" | /// 
												      och_missedsch_why_oth_`i' == "Ne sais pas"
											  
replace och_missedsch_why_oth_`i' = "" if och_missedsch_why_oth_`i' == "SUR UNE AUTRE VILLE" | ///   
	                                                  och_missedsch_why_oth_`i' == "Ne sait pas" | /// 
	                 och_missedsch_why_oth_`i' == "POUR LE MOMENT IL FAIT SES ÉTUDES À KINSHASA" | /// 
	                                             och_missedsch_why_oth_`i' == "IL EST À KANANGA" | /// 
	                             och_missedsch_why_oth_`i' == "IL N 'EST PAS ICI IL EST À ILEBO" | /// 
	                              och_missedsch_why_oth_`i' == "Elle et lui ailleurs à  Kananga" | /// 
	                                          och_missedsch_why_oth_`i' == "Il EST À LUBUMBASHI" | /// 
											      och_missedsch_why_oth_`i' == "POUR LES ÉTUDES" | /// 
												      och_missedsch_why_oth_`i' == "Ne sais pas"

list survey_hh_id och_schooling_`i' och_attendsch_lwks_`i' och_missedsch_why_oth_`i' if och_missedsch_why_oth_`i' != ""
 }


*br nch_missedsch_why_4 nch_missedsch_why_4_4 nch_missedsch_why__555_4 nch_missedsch_why_oth_4 if nch_missedsch_why_oth_4 != ""

forvalues i=1/6{

replace nch_missedsch_why_`i' = subinstr(nch_missedsch_why_`i', "-555", "4", .) /// 
                            if nch_missedsch_why_oth_`i' == "CONGE DE NOËL" | /// 
                               nch_missedsch_why_oth_`i' == "CONGE DE NOEL" | /// 
                        nch_missedsch_why_oth_`i' == "FETE DE NOUVELLE ANS" | /// 
            nch_missedsch_why_oth_`i' == "EN VACANCES DE NOEL ET NOUVEL AN" | /// 
		nch_missedsch_why_oth_`i' == "Il y avait la vacance de fin d'année"
			
   
replace nch_missedsch_why_4_`i' = 1 if nch_missedsch_why_oth_`i' == "CONGE DE NOËL" | /// 
                                     nch_missedsch_why_oth_`i' == "CONGE DE NOEL"   | /// 
                              nch_missedsch_why_oth_`i' == "FETE DE NOUVELLE ANS"   | /// 
                  nch_missedsch_why_oth_`i' == "EN VACANCES DE NOEL ET NOUVEL AN"   | /// 
		nch_missedsch_why_oth_`i' == "Il y avait la vacance de fin d'année"   
			
replace nch_missedsch_why__555_`i' = 0 if nch_missedsch_why_oth_`i' == "CONGE DE NOËL" | /// 
                                        nch_missedsch_why_oth_`i' == "CONGE DE NOEL"   | /// 
                                 nch_missedsch_why_oth_`i' == "FETE DE NOUVELLE ANS"   | /// 
                  nch_missedsch_why_oth_`i' == "EN VACANCES DE NOEL ET NOUVEL AN"      | ///  
		nch_missedsch_why_oth_`i' == "Il y avait la vacance de fin d'année"
				  
replace nch_missedsch_why_oth_`i' = "" if nch_missedsch_why_oth_`i' == "CONGE DE NOËL" | /// 
                                        nch_missedsch_why_oth_`i' == "CONGE DE NOEL" | /// 
                                 nch_missedsch_why_oth_`i' == "FETE DE NOUVELLE ANS" | /// 
                  nch_missedsch_why_oth_`i' == "EN VACANCES DE NOEL ET NOUVEL AN" | /// 
		nch_missedsch_why_oth_`i' == "Il y avait la vacance de fin d'année"
				  
list nch_schooling_`i' nch_attendsch_lwks_`i' nch_missedsch_why_oth_`i' if nch_missedsch_why_oth_`i' != ""

}	

** Create answer choice 8 referring to Teacher's strike
forvalues i=1/6{
gen nch_missedsch_why_8_`i' =.
}

forvalues i=1/6{
replace nch_missedsch_why_`i' = subinstr(nch_missedsch_why_`i', "-555", "8", .) /// 
                     if nch_missedsch_why_oth_`i' == "GREVE DES ENSEIGNATS" | /// 
                                       nch_missedsch_why_oth_`i' == "GREVE" | /// 
                       nch_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE." | /// 
					  nch_missedsch_why_oth_`i' == "ENSEIGNANTS  EN GRÈVE." | /// 
					   nch_missedsch_why_oth_`i' == "GREVE DES ENSEIGNANTS" | ///  
					    nch_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE"
						

replace nch_missedsch_why_8_`i' = 1 if nch_missedsch_why_oth_`i' == "GREVE DES ENSEIGNATS" | /// 
                                                      nch_missedsch_why_oth_`i' == "GREVE" | /// 
                                    nch_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE."   | /// 
									 nch_missedsch_why_oth_`i' == "ENSEIGNANTS  EN GRÈVE." | /// 
					                  nch_missedsch_why_oth_`i' == "GREVE DES ENSEIGNANTS" | ///  
					                   nch_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE"
									
replace nch_missedsch_why__555_`i' = 0 if nch_missedsch_why_oth_`i' == "GREVE DES ENSEIGNATS" | /// 
                                                         nch_missedsch_why_oth_`i' == "GREVE" | /// 
                                       nch_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE."   | /// 
									    nch_missedsch_why_oth_`i' == "ENSEIGNANTS  EN GRÈVE." | /// 
					                     nch_missedsch_why_oth_`i' == "GREVE DES ENSEIGNANTS" | ///  
					                      nch_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE"
									
replace nch_missedsch_why_oth_`i' = "" if nch_missedsch_why_oth_`i' == "GREVE DES ENSEIGNATS" | /// 
                                                         nch_missedsch_why_oth_`i' == "GREVE" | /// 
                                       nch_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE."   | /// 
									    nch_missedsch_why_oth_`i' == "ENSEIGNANTS  EN GRÈVE." | /// 
					                     nch_missedsch_why_oth_`i' == "GREVE DES ENSEIGNANTS" | ///  
					                      nch_missedsch_why_oth_`i' == "ENSEIGNANTS EN GREVE"
									   
list nch_schooling_`i' nch_attendsch_lwks_`i' nch_missedsch_why_oth_`i' if nch_missedsch_why_oth_`i' != ""

}

 
 **** Child is not schooling (Turn all related variables to missing and nch_schooling_1 to 0)
replace nch_missedsch_why_1 = subinstr(nch_missedsch_why_1, "-555", "", .) if nch_missedsch_why_oth_1 == "ELLE N'A PAS ENCORE ATTEINT L'ÂGE SCOLAIRE"
replace nch_missedsch_why__555_1 = . if nch_missedsch_why_oth_1 == "ELLE N'A PAS ENCORE ATTEINT L'ÂGE SCOLAIRE"
replace nch_attendsch_lwks_1 = . if nch_missedsch_why_oth_1 == "ELLE N'A PAS ENCORE ATTEINT L'ÂGE SCOLAIRE"
replace nch_schooling_1 = 0 if nch_missedsch_why_oth_1 == "ELLE N'A PAS ENCORE ATTEINT L'ÂGE SCOLAIRE"
replace nch_missedsch_why_oth_1 = "" if nch_missedsch_why_oth_1 == "ELLE N'A PAS ENCORE ATTEINT L'ÂGE SCOLAIRE"
 
 *** Respondent does not know if child went to school the past week or not (missing code in nch_attendsch_lwks: .d)
 
 forvalues i=1/6{
replace nch_missedsch_why_`i' = subinstr(nch_missedsch_why_`i', "-555", "", .) if /// 
                                              nch_missedsch_why_oth_`i' == "SUR UNE AUTRE VILLE" | /// 
	nch_missedsch_why_oth_`i' == "L' ENFANT N EST PAS SUR PLE IL EST À ILEBO, ELLE NE SAIT PLUS" | ///  
	                                                  nch_missedsch_why_oth_`i' == "Ne sait pas" | /// 
	                 nch_missedsch_why_oth_`i' == "POUR LE MOMENT IL FAIT SES ÉTUDES À KINSHASA" | /// 
	                                             nch_missedsch_why_oth_`i' == "IL EST À KANANGA" | /// 
	                             nch_missedsch_why_oth_`i' == "IL N 'EST PAS ICI IL EST À ILEBO" | /// 
	                              nch_missedsch_why_oth_`i' == "Elle et lui ailleurs à  Kananga" | /// 
	                                          nch_missedsch_why_oth_`i' == "Il EST À LUBUMBASHI" | /// 
											      nch_missedsch_why_oth_`i' == "POUR LES ÉTUDES"

replace nch_missedsch_why__555_`i' = . if nch_missedsch_why_oth_`i' == "SUR UNE AUTRE VILLE" | /// 
	nch_missedsch_why_oth_`i' == "L' ENFANT N EST PAS SUR PLE IL EST À ILEBO, ELLE NE SAIT PLUS" | ///  
	                                                  nch_missedsch_why_oth_`i' == "Ne sait pas" | /// 
	                 nch_missedsch_why_oth_`i' == "POUR LE MOMENT IL FAIT SES ÉTUDES À KINSHASA" | /// 
	                                             nch_missedsch_why_oth_`i' == "IL EST À KANANGA" | /// 
	                             nch_missedsch_why_oth_`i' == "IL N 'EST PAS ICI IL EST À ILEBO" | /// 
	                              nch_missedsch_why_oth_`i' == "Elle et lui ailleurs à  Kananga" | /// 
	                                          nch_missedsch_why_oth_`i' == "Il EST À LUBUMBASHI" | /// 
											      nch_missedsch_why_oth_`i' == "POUR LES ÉTUDES"
											  
replace nch_attendsch_lwks_`i' = .d if nch_missedsch_why_oth_`i' == "SUR UNE AUTRE VILLE" | /// 
	nch_missedsch_why_oth_`i' == "L' ENFANT N EST PAS SUR PLE IL EST À ILEBO, ELLE NE SAIT PLUS" | ///  
	                                                  nch_missedsch_why_oth_`i' == "Ne sait pas" | /// 
	                 nch_missedsch_why_oth_`i' == "POUR LE MOMENT IL FAIT SES ÉTUDES À KINSHASA" | /// 
	                                             nch_missedsch_why_oth_`i' == "IL EST À KANANGA" | /// 
	                             nch_missedsch_why_oth_`i' == "IL N 'EST PAS ICI IL EST À ILEBO" | /// 
	                              nch_missedsch_why_oth_`i' == "Elle et lui ailleurs à  Kananga" | /// 
	                                          nch_missedsch_why_oth_`i' == "Il EST À LUBUMBASHI" | /// 
											      nch_missedsch_why_oth_`i' == "POUR LES ÉTUDES"
											  
replace nch_missedsch_why_oth_`i' = "" if nch_missedsch_why_oth_`i' == "SUR UNE AUTRE VILLE" | /// 
	nch_missedsch_why_oth_`i' == "L' ENFANT N EST PAS SUR PLE IL EST À ILEBO, ELLE NE SAIT PLUS" | ///  
	                                                  nch_missedsch_why_oth_`i' == "Ne sait pas" | /// 
	                 nch_missedsch_why_oth_`i' == "POUR LE MOMENT IL FAIT SES ÉTUDES À KINSHASA" | /// 
	                                             nch_missedsch_why_oth_`i' == "IL EST À KANANGA" | /// 
	                             nch_missedsch_why_oth_`i' == "IL N 'EST PAS ICI IL EST À ILEBO" | /// 
	                              nch_missedsch_why_oth_`i' == "Elle et lui ailleurs à  Kananga" | /// 
	                                          nch_missedsch_why_oth_`i' == "Il EST À LUBUMBASHI" | /// 
											      nch_missedsch_why_oth_`i' == "POUR LES ÉTUDES"

list nch_schooling_`i' nch_attendsch_lwks_`i' nch_missedsch_why_oth_`i' if nch_missedsch_why_oth_`i' != ""
 }

**** Water use expenditure variables
*br if flatrate_period == -555
tab province flatrate_fee
tab province flatrate_period
*tab province peruse_fee
tab province wateruse_cost
*tab province peruse_fee_20liter

*tab peruse_fee, mi
tab flatrate_period, mi nol
*tab flatrate_period_name, mi
tab flatrate_fee, mi
*tab peruse_fee_20liter, mi
*tab paid_water_lstwk, mi
tab water_peruse_pay_lastwk, mi
*tab water_flatrate_pay_lastwk, mi
*tab water_totqty_lastweek, mi
*tab water_trip_count_lastwk, mi

*tab mainjc_capacity, mi

*tab peruse_fee peruse_fee_20liter

*br key health_zone flatrate_period flatrate_period_name flatrate_fee paid_water_lstwk water_flatrate_pay_lastwk comment_flatrate_period comment_flatrate_fee comment if flatrate_period == -555

label define flatrate_period 7 "Once every three months", add
label value flatrate_period flatrate_period

replace flatrate_period = 7 if key == "uuid:ee346660-1e8c-4084-b328-fca577520291" | /// 
							   key == "uuid:f857ad43-ceaa-48e5-b606-8ed53b630548" | /// 
							   key == "uuid:b710ee9a-f13d-4dcc-b2a4-f45ab47303b8" | /// 
							   key == "uuid:b1d8e77a-5b43-47d9-856e-d3646572e97c" | /// 
							   key == "uuid:ad3af5b7-94db-42a9-90cf-bbf8ffb47da0" | /// 
							   key == "uuid:abdad566-6bc1-4a9d-97e5-515e633f24a8" | /// 
							   key == "uuid:a5c2c7ee-0694-4aa0-a9bc-e4525f4a74cf" | /// 
							   key == "uuid:9c967385-9bba-4097-b1a9-a7900f6f3b1a" | /// 
							   key == "uuid:95556989-a274-41f3-8f44-6184f1900fab" | /// 
							   key == "uuid:76116b6c-9702-4f09-9eac-7efe55856b62" | /// 
							   key == "uuid:7003d721-d6a8-4baa-9a42-709708db467f" | /// 
							   key == "uuid:62f00a9b-4795-4f49-97fb-edfa891b9e40" | /// 
							   key == "uuid:4e98a6c2-3456-4b8d-9656-6510d7b325ad" | /// 
							   key == "uuid:4d12a2f6-40e1-42d2-979b-b0d629e4788e" | /// 
							   key == "uuid:2857df8b-02bc-4e8b-bd29-82342755edda" | /// 
							   key == "uuid:246ed885-0909-4f58-81dd-a5b54920278f" | /// 
							   key == "uuid:1f387301-5cdc-4837-84ef-e5c43f598256" | /// 
							   key == "uuid:1eec1d45-fb76-4247-aba3-553297e67aaa" | /// 
							   key == "uuid:0d980849-0b51-4454-9dcb-85267d16830b" | /// 
							   key == "uuid:0b8b8470-1064-4d2c-b609-a755ae43e3b4" | /// 
							   key == "uuid:05df30a7-9571-49dc-ba41-a89705a2bab5" | /// 
							   key == "uuid:051bb25b-ed1a-4969-9c72-84508659e27a" | /// 
							   key == "uuid:038579e0-3b7f-450d-aeef-1ca4593aa557" 

tab flatrate_period, mi
drop comment_flatrate_fee comment_flatrate_period
						   
							   							   


**** Clean age and sex variable 
* Sex
tab pl_childold_gender_1, mi
tab pl_childold_gender_1, mi nol

forvalues i=1/23{
replace pl_childold_gender_`i' = "Female" if pl_childold_gender_`i' == "Femme"
replace pl_childold_gender_`i' = "Male" if pl_childold_gender_`i' == "Homme"
}



* Age
tab nch_child_sex_1, mi 
tab nch_child_sex_1, mi nol

tab nch_age_years_calc_1, mi

forvalues i=1/6{
tab nch_age_years_calc_`i', mi
replace nch_age_years_calc_`i' = .d if nch_age_years_calc_`i' == -999
replace nch_age_years_calc_`i' = .r if nch_age_years_calc_`i' == -888
replace nch_age_years_calc_`i' = .d if nch_age_years_calc_`i' == -777

tab nch_age_years_calc2_`i', mi 
replace nch_age_years_calc2_`i' = .d if nch_age_years_calc2_`i' == -999
replace nch_age_years_calc2_`i' = .r if nch_age_years_calc2_`i' == -888
replace nch_age_years_calc2_`i' = .d if nch_age_years_calc2_`i' == -777
}

forvalues i=1/23{
tab och_age_years_calc_`i', mi
replace och_age_years_calc_`i' = .d if och_age_years_calc_`i' == -999
replace och_age_years_calc_`i' = .r if och_age_years_calc_`i' == -888
replace och_age_years_calc_`i' = .d if och_age_years_calc_`i' == -777

tab och_age_years_calc2_`i', mi
replace och_age_years_calc2_`i' = .d if och_age_years_calc2_`i' == -999
replace och_age_years_calc2_`i' = .r if och_age_years_calc2_`i' == -888
replace och_age_years_calc2_`i' = .d if och_age_years_calc2_`i' == -777
}

******** save clean dataset ready for variable construction
save "${hp_hh_clean}", replace


* end of dofile *
