/*******************************************************************************

Title: 			05_hhw_construct_health_paper.do
Author(s): 		Caleb Jeremie Dohou & Luca Stanus Ghib
Description: 	This dofile loads the clean data and constructs variables and indices.
Input: 	"${clean}", see global defined in Project_MasterDofile.do
Output:	"${constructed}", see global defined in  Project_MasterDofile.do

*******************************************************************************/


******** load raw dataset
use "${hp_hhw_clean}", clear

******** construction section
* merge treatment_status, group (cluster) and cluster_strata from village list
merge m:1 village using "${hp_village_list}", keepusing(treatment_status group cluster_strata) update // 3 not matched from using; These are the 3 villages not surveyed at endline.


**** Continuous measure for water risk ****
gen double water_risk_mpn = .

* Row 1 - MPN Table 
replace water_risk_mpn = 0.0 if (color_compart1_10 == 1 & color_compart2_30 == 1 & color_compart3_56 == 1 & color_compart4_03 == 1 & color_compart5_01 == 1) 


* Row 2 - MPN Table discrepancy
replace water_risk_mpn = 1.0 if (color_compart1_10 == 1 & color_compart2_30 == 1 & color_compart3_56 == 1 & (color_compart4_03 == 2 | color_compart4_03 == 3) & color_compart5_01 == 1)


* Row 3 - MPN Table discrepancy
replace water_risk_mpn = 1.0 if (color_compart1_10 == 1 & color_compart2_30 == 1 & color_compart3_56 == 1 & color_compart4_03 == 1 & (color_compart5_01 == 2 | color_compart5_01 == 3))


* Row 4 - MPN Table discrepancy
replace water_risk_mpn = 1.1 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & color_compart2_30 == 1 & color_compart3_56 == 1 & color_compart4_03 == 1 & color_compart5_01 == 1)


* Row 5 - MPN Table discrepancy
replace water_risk_mpn = 1.2 if (color_compart1_10 == 1 & (color_compart2_30 == 2 | color_compart2_30 == 3) & color_compart3_56 == 1 & color_compart4_03 == 1 & color_compart5_01 == 1)


* Row 6 - MPN Table discrepancy
replace water_risk_mpn = 1.5 if (color_compart1_10 == 1 & color_compart2_30 == 1 & (color_compart3_56 == 2 | color_compart3_56 == 3) & color_compart4_03 == 1 & color_compart5_01 == 1)


* Row 7 - MPN Table discrepancy
replace water_risk_mpn = 2.0 if (color_compart1_10 == 1 & color_compart2_30 == 1 & color_compart3_56 == 1 & (color_compart4_03 == 2 | color_compart4_03 == 3) & (color_compart5_01 == 2 | color_compart5_01 == 3))


* Row 8 - MPN Table discrepancy
replace water_risk_mpn = 2.1 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & color_compart2_30 == 1 & color_compart3_56 == 1 & (color_compart4_03 == 2 | color_compart4_03 == 3) & color_compart5_01 == 1)


* Row 9 - MPN Table discrepancy
replace water_risk_mpn = 2.1 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & color_compart2_30 == 1 & color_compart3_56 == 1 & color_compart4_03 == 1 & (color_compart5_01 == 2 | color_compart5_01 == 3))


* Row 10 - MPN Table discrepancy
replace water_risk_mpn = 2.4 if (color_compart1_10 == 1 & (color_compart2_30 == 2 | color_compart2_30 == 3) & color_compart3_56 == 1 & (color_compart4_03 == 2 | color_compart4_03 == 3) & color_compart5_01 == 1)


* Row 11 - MPN Table discrepancy
replace water_risk_mpn = 2.4 if (color_compart1_10 == 1 & (color_compart2_30 == 2 | color_compart2_30 == 3) & color_compart3_56 == 1 & color_compart4_03 == 1 & (color_compart5_01 == 2 |color_compart5_01 == 3))


* Row 12 - MPN Table discrepancy
replace water_risk_mpn = 2.6 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & (color_compart2_30 == 2 | color_compart2_30 == 3) & color_compart3_56 == 1 & color_compart4_03 == 1 & color_compart5_01 == 1)


* Row 13 - MPN Table discrepancy
replace water_risk_mpn = 3.2 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & color_compart2_30 == 1 & color_compart3_56 == 1 & (color_compart4_03 == 2 | color_compart4_03 == 3) & (color_compart5_01 == 2 | color_compart5_01 == 3))

* Row 14 - MPN Table discrepancy
replace water_risk_mpn = 3.7 if (color_compart1_10 == 1 & (color_compart2_30 == 2 | color_compart2_30 == 3) & color_compart3_56 == 1 & (color_compart4_03 == 2 | color_compart4_03 == 3) & (color_compart5_01 == 2 | color_compart5_01 == 3))


* Row 15 - MPN Table discrepancy
replace water_risk_mpn = 3.1 if (color_compart1_10 == 1 & color_compart2_30 == 1 & (color_compart3_56 == 2 | color_compart3_56 == 3) & color_compart4_03 == 1 & (color_compart5_01 == 2 | color_compart5_01 == 3))


* Row 16 - MPN Table discrepancy
replace water_risk_mpn = 3.2 if (color_compart1_10 == 1 & color_compart2_30 == 1 & (color_compart3_56 == 2 | color_compart3_56 == 3) & (color_compart4_03 == 2 | color_compart4_03 == 3) & color_compart5_01 == 1)


* Row 17 - MPN Table discrepancy
replace water_risk_mpn = 3.4 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & color_compart2_30 == 1 & (color_compart3_56 == 2 | color_compart3_56 == 3) & color_compart4_03 == 1 & color_compart5_01 == 1)


* Row 18 - MPN Table discrepancy
replace water_risk_mpn = 3.9 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & (color_compart2_30 == 2 | color_compart2_30 == 3) & color_compart3_56 == 1 & color_compart4_03 == 1 & (color_compart5_01 == 2 |color_compart5_01 == 3))


* Row 19 - MPN Table discrepancy
replace water_risk_mpn = 4.0 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & (color_compart2_30 == 2 | color_compart2_30 == 3) & color_compart3_56 == 1 & (color_compart4_03 == 2 | color_compart4_03 == 3) & color_compart5_01 == 1)


* Row 20 - MPN Table discrepancy
replace water_risk_mpn = 4.7 if (color_compart1_10 == 1 & (color_compart2_30 == 2 | color_compart2_30 == 3) & (color_compart3_56 == 2 | color_compart3_56 == 3) & color_compart4_03 == 1 & color_compart5_01 == 1)


* Row 21 - MPN Table discrepancy
replace water_risk_mpn = 5.2 if (color_compart1_10 == 1 & color_compart2_30 == 1 & (color_compart3_56 == 2 | color_compart3_56 == 3) & (color_compart4_03 == 2 | color_compart4_03 == 3) & (color_compart5_01 == 2 | color_compart5_01 == 3))

* Row 22 - MPN Table discrepancy
replace water_risk_mpn = 5.4 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & (color_compart2_30 == 2 | color_compart2_30 == 3) & color_compart3_56 == 1 & (color_compart4_03 == 2 | color_compart4_03 == 3) & (color_compart5_01 == 2 | color_compart5_01 == 3))


* Row 23 - MPN Table discrepancy
replace water_risk_mpn = 5.6 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & color_compart2_30 == 1 & (color_compart3_56 == 2 | color_compart3_56 == 3) & color_compart4_03 == 1 & (color_compart5_01 == 2 | color_compart5_01 == 3))


* Row 24 - MPN Table discrepancy
replace water_risk_mpn = 5.8 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & color_compart2_30 == 1 & (color_compart3_56 == 2 | color_compart3_56 == 3) & (color_compart4_03 == 2 | color_compart4_03 == 3) & color_compart5_01 == 1)

* Row 25 - MPN Table discrepancy
replace water_risk_mpn = 8.4 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & color_compart2_30 == 1 & (color_compart3_56 == 2 | color_compart3_56 == 3) & (color_compart4_03 == 2 | color_compart4_03 == 3) & (color_compart5_01 == 2 | color_compart5_01 == 3))


* Row 26 - MPN Table discrepancy
replace water_risk_mpn = 9.1 if (color_compart1_10 == 1 & (color_compart2_30 == 2 | color_compart2_30 == 3) & (color_compart3_56 == 2 | color_compart3_56 == 3) & color_compart4_03 == 1 & (color_compart5_01 == 2 | color_compart5_01 == 3))


* Row 27 - MPN Table discrepancy
replace water_risk_mpn = 9.6 if (color_compart1_10 == 1 & (color_compart2_30 == 2 | color_compart2_30 == 3) & (color_compart3_56 == 2 | color_compart3_56 == 3) & (color_compart4_03 == 2 | color_compart4_03 == 3) & color_compart5_01 == 1)


* Row 28 - MPN Table discrepancy
replace water_risk_mpn = 13.6 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & (color_compart2_30 == 2 | color_compart2_30 == 3) & (color_compart3_56 == 2 | color_compart3_56 == 3) & color_compart4_03 == 1 & color_compart5_01 == 1)


* Row 29 - MPN Table discrepancy
replace water_risk_mpn = 17.1 if  (color_compart1_10 == 1 & (color_compart2_30 == 2 | color_compart2_30 == 3) & (color_compart3_56 == 2 | color_compart3_56 == 3) & (color_compart4_03 == 2 | color_compart4_03 == 3) & (color_compart5_01 == 2 | color_compart5_01 == 3))


* Row 30 - MPN Table discrepancy
replace water_risk_mpn = 32.6 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & (color_compart2_30 == 2 | color_compart2_30 == 3) & (color_compart3_56 == 2 | color_compart3_56 == 3) & color_compart4_03 == 1 & (color_compart5_01 == 2 | color_compart5_01 == 3))


* Row 31 - MPN Table discrepancy
replace water_risk_mpn = 48.3 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & (color_compart2_30 == 2 | color_compart2_30 == 3) & (color_compart3_56 == 2 | color_compart3_56 == 3) & (color_compart4_03 == 2 | color_compart4_03 == 3) & color_compart5_01 == 1)


* Row 32 - MPN Table discrepancy (MPN>100 -- Troncated at 100)
replace water_risk_mpn = 100 if ((color_compart1_10 == 2 | color_compart1_10 == 3) & (color_compart2_30 == 2 | color_compart2_30 == 3) & (color_compart3_56 == 2 | color_compart3_56 == 3) & (color_compart4_03 == 2 | color_compart4_03 == 3) & (color_compart5_01 == 2 | color_compart5_01 == 3))

label variable water_risk_mpn "Water Risk: Most Probable Number per 100mL (MPN/100mL)"

sum water_risk_mpn
tab water_risk_mpn, mi

******* Log of continuous water risk measure (Log of MPN)
* Correcting for zeroes before applying log *
*
* Erucmen, Pickering, Arnold et al 2018 claim: "We substituted bacterial counts with half the lower detection 
* limit for nondetects." The test-maker tells us that the uncensored lower detection limit is 1.0-1.5/100 mL. So 
* it seems that if we want to follow Erucmen et al, we substitute 1.25/2 = 0.625 for the zeroes.
*
tab water_risk_mpn, mi
gen water_risk_logmpn = log10(cond(water_risk_mpn, water_risk_mpn, 0.625, .))

label variable water_risk_mpn "Water Risk: Log of Most Probable Number per 100 mL (MPN/100mL)"

sum(water_risk_logmpn)
tab water_risk_logmpn, mi


******** save constructed dataset ready for analysis
save "${hp_hhw_constructed}", replace


* end of dofile *
