/*******************************************************************************

Title: 			06_analysis.do
Author(s): 		Luca Stanus Ghib
Description: 	This dofile produces combined table for primary outcomes table.
Input: 	"${hp_hh_child_roster}", see global defined in Project_MasterDofile.do
Output:	tables

*******************************************************************************/
	
	
	
	* load midline VL data
use "${midl_vl_constructed}", clear


** Correction of village code and IDs in midline data
replace village = "455432" if key == "uuid:f5fed058-c61e-4def-9447-952531d3d929"
replace village_id = 455432 if key == "uuid:f5fed058-c61e-4def-9447-952531d3d929"

replace survey_leadership_id = "VL455432" if key == "uuid:f5fed058-c61e-4def-9447-952531d3d929"


** Correction of village code and IDs in midline data
replace village = "455433" if key == "uuid:0e2214e1-9540-4beb-8692-8ad132d6de50"
replace village_id = 455433 if key == "uuid:0e2214e1-9540-4beb-8692-8ad132d6de50"

replace survey_leadership_id = "VL455433" if key == "uuid:0e2214e1-9540-4beb-8692-8ad132d6de50" 


	gen     vea_step6_complete_midl =  vea_step6_complete
	recode 	vea_step6_complete_midl (5 = 1) (1 2 3 4 6 = 0)
	
	rename submissiondate submissiondate_midl
	rename interview_end_time interview_end_time_midl
	
	rename vea_step6_end_m vea_step6_end_m_midl
	rename vea_step6_end_y vea_step6_end_y_midl
	
ds village survey_leadership_id province vea_step6_complete_midl vea_step6_end_m_midl vea_step6_end_y_midl submissiondate_midl interview_end_time_midl treatment_status

keep `r(varlist)'


tempfile midl_vl_data
save `midl_vl_data', replace


	
	**** Institution Table for Lancet paper

	
	use "${endl_vl_constructed}", clear // Load VL constructed data
	

ds province health_zone hz_name health_area ha_name village village_name survey_leadership_id consent treatment_status vea_step6_complete step6_complete  step6_complete_when_y step6_complete_when_m date_visit submissiondate 

keep `r(varlist)'


destring vea_step6_complete, replace


gen vea_step6_complete_endl = vea_step6_complete
		
		
tab step6_complete_when_y step6_complete_when_m, mi


		replace vea_step6_complete_endl = 1 if vea_step6_complete == 0 & step6_complete == 1
		
		tab vea_step6_complete, mi
		tab vea_step6_complete_endl, mi

rename step6_complete_when_y step6_complete_when_y_endl
rename step6_complete_when_m step6_complete_when_m_endl

rename date_visit date_visit_endl
rename submissiondate submissiondate_endl


*   

merge 1:1 survey_leadership_id using "`midl_vl_data'", update


replace vea_step6_complete_endl = vea_step6_complete_midl if survey_leadership_id == "VL211111" // Vilage not surveyed at endline due to internal conflicts
		tab vea_step6_complete_midl, mi
		tab vea_step6_complete_endl, mi
		tab vea_step6_complete_midl vea_step6_complete_endl, mi
	
 
tab1 step6_complete_when_y_endl step6_complete_when_m_endl, mi
tab1 vea_step6_end_m_midl vea_step6_end_y_midl, mi

gen step6_complete_year = vea_step6_end_y_midl
replace step6_complete_year = step6_complete_when_y_endl if step6_complete_when_y_endl != . & step6_complete_year == .

tab step6_complete_year, mi


gen step6_complete_month = vea_step6_end_m_midl
replace step6_complete_month = step6_complete_when_m_endl if step6_complete_when_m_endl != . & step6_complete_month == .

tab step6_complete_month, mi

tab step6_complete_month step6_complete_year , mi

count if treatment_status == 1 & step6_complete_year != .
count if step6_complete_year != .	
count if treatment_status == 0 & step6_complete_year != .

count if treatment_status == 1 & step6_complete_year != . & step6_complete_month != .
count if treatment_status == 1 & step6_complete_year != . & step6_complete_month != . & submissiondate_endl != .

count if treatment_status == 0 & step6_complete_year != . & step6_complete_month != .

count if treatment_status == 0 & step6_complete_year != . & step6_complete_month != . & submissiondate_endl != .



br if survey_leadership_id == "VL211111"
count if submissiondate_endl == .

replace step6_complete_year = . if step6_complete_year != . & step6_complete_month == .d

gen step6_complete_date = ym(step6_complete_year, step6_complete_month) 
format step6_complete_date %tm


* Step 1: Generate a new variable to extract just the date part
gen date_endline = dofc(date_visit_endl)

* Step 2: Create a new variable in the "2019m10" format by combining the year and month
gen date_endl = string(year(date_endline)) + "m" + string(month(date_endline), "%02.0f")

* Step 1: Convert string date (e.g., "Oct2019") to a Stata monthly date
gen date_endl1 = monthly(date_endl, "YM")

* Step 2: Format the new numeric variable as "Ym"
format date_endl1 %tm



gen follow_up_survey = date_endl1 - step6_complete_date

gen follow_up_survey1 = follow_up_survey/12

label var follow_up_survey1 "Time - End of Program and Endline Survey"

sum follow_up_survey1, d

winsor2 follow_up_survey1, ///
 cuts(0 99) suffix(_win99) label
sum follow_up_survey1_win99, d
sum follow_up_survey1_win99

label var follow_up_survey1_win99 "Time - End of Program and Endline Survey"


estpost tabstat follow_up_survey1_win99 if follow_up_survey1_win99 != ., c(stat) stat(mean sd p50 min max)

	esttab using  "${hp_tables}/time_end_step6_endline_survey.csv", replace /// 
	cells("mean(fmt(%9.2fc)) sd(fmt(%9.2fc)) p50(fmt(%9.2fc)) min(fmt(%12.0f)) max(fmt(%12.0f))") /// 
	nonumb noobs label nomtitle compress nonote ///
	collabels("Mean" "SD" "Median" "Min" "Max")
	//title("Time between End of VEA Step 6 and Endline survey")
exit 








	


	
* end of dofile *
