/*******************************************************************************

Title: 			table_s7_health_paper.do
Author(s): 		Caleb Jeremide Dohou
Description: 	This dofile produces table s7: Gender subgroup analysis. Table S7. Intervention effects on diarrhea and length-for-age z score, sex-by-intervention interaction models
Input: 	"${hp_hh_child_roster}", "${hp_anthro_z_constructed}", see global defined in Project_MasterDofile.do
Output:	"${hp_tables}/table_s7_hp.csv"

*******************************************************************************/	
	
	
********************************************************************************
* Gender Heterogenous Analysis
********************************************************************************

*Endline Diarhea Subgroup Analysis by child gender and Interaction term
*Used noparen option
*Using FEs for province and cluster size
*Using standard errors clustered around "group"


**** Length for age
	use "${hp_anthro_z_constructed}", clear // Load Anthro constructed data
	

label var _zlen "Height for age"
label var _zwfl "Weight for length"
label var _zwei "Weight for age"


local outcomes _zlen _zwfl _zwei
local indepvar treatment_status 

*local i = 1

foreach depvar in `outcomes'{

reg `depvar' `indepvar' child_sex child_age_years i.province#cluster_strata, vce(cluster group)

*local i = `++i'

*disp "`i'"

* est sto `depvar'_mod`i'
est sto `depvar'_simple

}


**** Length for age 
	use "${hp_anthro_z_constructed}", clear // Load Anthro constructed data
	

label var _zlen "Height for age"
label var _zwfl "Weight for length"
label var _zwei "Weight for age"


local outcomes _zlen _zwfl _zwei
local indepvar treatment_status 

*local i = 1

foreach depvar in `outcomes'{

reg `depvar' `indepvar' child_sex child_age_years treatment_status##child_sex i.province#cluster_strata, vce(cluster group)

*local i = `++i'

*disp "`i'"

* est sto `depvar'_mod`i'
est sto `depvar'_interaction

}



******** load child-level dataset
use "${hp_hh_child_roster}", clear

label var diarrhea_outcome "Diarrhea"
label var child_sex "Child's sex"
label var child_age_years "Child's age (years)"
label var treatment_status "Treatment"

gen _zlen = .
gen _zwfl = .
gen _zwei = . 

label var _zlen "Height for age"
label var _zwfl "Weight for height"
label var _zwei "Weight for age"

local depvar diarrhea_outcome
local indepvar treatment_status 

reg `depvar' `indepvar' child_sex child_age_years i.province#cluster_strata, vce(cluster group)


est sto diarrhea_simple


******** load child-level dataset
use "${hp_hh_child_roster}", clear

label var diarrhea_outcome "Diarrhea"
label var child_sex "Child's sex"
label var child_age_years "Child's age (years)"
label var treatment_status "Treatment"

gen _zlen = .
gen _zwfl = .
gen _zwei = . 

label var _zlen "Height for age"
label var _zwfl "Weight for height"
label var _zwei "Weight for age"

local depvar diarrhea_outcome
local indepvar treatment_status 

reg `depvar' `indepvar' child_sex child_age_years treatment_status##child_sex i.province#cluster_strata, vce(cluster group)

est sto diarrhea_interaction


*/		
esttab 	diarrhea_simple diarrhea_interaction _zlen_simple _zlen_interaction _zwfl_simple _zwfl_interaction _zwei_simple _zwei_interaction ///
		using "${hp_tables}/table_s7_hp.csv", ///
		replace se label noomitted nobaselevels   ///
		star(* .1 ** .05 *** .01) ///
		b(%9.3f) se(%9.3f) ///
		mtitles("Diarrhea - Simple" "Diarrhea - Interaction" "Height for Age - Simple" "Height for Age - Interaction" "Weight for Height - Simple" "Weight for Height - Interaction" "Weight for Age - Simple" "Weight for Age - Interaction") wrap unstack depvars


* end of subgroup table *

	
* end of dofile *
