/*******************************************************************************

Title: 			table_2_health_paper.do
Author(s): 		Caleb Jeremie Dohou & Luca Stanus Ghib
Description: 	This dofile produces output. Table 2. Household and respondent characteristics by intervention group, at 3.5-year follow-up
Input: 	"${hp_hh_constructed}", see global defined in Project_MasterDofile.do
Output:	"${hp_tables}/table_2_hp.xlsx"

*******************************************************************************/

******* Household-level improved water source & improved sanitation analysis
* load HH-level dataset
use "${hp_hh_constructed}", clear


	***** Diarrhea Table for Lancet paper
global hhbalance improvedroof improvedwall improvedfloor hhsize catholic protestant other_religion resp_age resp_prim_sch_complete resp_sec_sch_complete marriedorcohab

** add labels/headers via putexcel directly
mat results = J(`: word count $hhbalance', 8, .)
forvalues i = 1/`: word count $hhbalance' {
	local var: word `i' of $hhbalance
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matlist r(table)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[4,1]
	*matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]= r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]= r(sd)
}
	
	matrix list results
	putexcel set "${hp_tables}/table_2_hp.xlsx", replace 
	
	* add headers
	putexcel A2 = "Outcomes"
	putexcel B1 = "Control"
	
	putexcel (B1:D1), merge hcenter
	
	putexcel B2 = "n"
	putexcel C2 = "Prevalence/Mean"
	putexcel D2 = "SD"
	putexcel E1 = "Intervention"
	
	putexcel (E1:G1), merge hcenter
	
	putexcel E2 = "n"
	putexcel F2 = "Prevalence/Mean"
	putexcel G2 = "SD"
	putexcel H2 = "ITT"
	putexcel I2 = "p-value"
	
	*putexcel (I2:J2), merge hcenter
	
	* add var labels
	putexcel A3  = "Household has improved roof" 
	putexcel A4  = "Household has improved wall" 
	putexcel A5  = "Household has improved floor" 
	putexcel A6  = "Household size" 
	putexcel A7  = "Respondent identifies as catholic" 
	putexcel A8  = "Respondent identifies as protestant" 
	putexcel A9 =  "Respondent identifies with other religion" 
	putexcel A10 = "Respondent age" 
	putexcel A11 = "Respondent has completed primary school" 
	putexcel A12 = "Respondent has completed secondary school"  
	putexcel A13 = "Respondent is married or cohabitating"
	* add reg table
	putexcel B3 = matrix(results), nformat(number_d2) 
	
	* Final formatting
	putexcel B3:B13, overwritefmt nformat(number)
	putexcel E3:E13, overwritefmt nformat(number)
	
	putexcel C10, overwritefmt nformat(number)
	putexcel F10, overwritefmt nformat(number)
	
		* end of table *

* end of dofile *
