/*******************************************************************************

Title: 			table_3_health_paper.do
Author(s): 		Luca Stanus Ghib
Description: 	This dofile produces combined table for primary outcomes table. Table 3. Intervention effects on primary outcomes: diarrhea, length-for-age, and WASH institutions 
Input: 	"${hp_hh_child_roster}", "${hp_anthro_z_constructed}", "${hp_vl_constructed}", see global defined in Project_MasterDofile.do
Output:	"${hp_tables}/table_3_hp.xlsx"

*******************************************************************************/

******** load child-level dataset
use "${hp_hh_child_roster}", clear

******** Child-level diarrhea analysis
	
***** Diarrhea 
global primary diarrhea_outcome

** add labels/headers via putexcel directly
mat results = J(`: word count $primary', 9, .)
forvalues i = 1/`: word count $primary' {
	local var: word `i' of $primary
	reg `var' treatment_status child_sex child_age_years i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
*	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
*	matrix results[`i',6]=r(sd)
}
	
	matrix list results
	putexcel set "${hp_tables}/table_3_hp.xlsx", replace 
	
	* add headers
	putexcel A2 = "Outcomes"
	putexcel B1 = "Control"
	
	putexcel (B1:D1), merge hcenter
	
	putexcel B2 = "n"
	putexcel C2 = "Prevalence/Mean"
	putexcel D2 = "SD"
	putexcel E1 = "Intervention"
	
	putexcel (E1:G1), merge hcenter
	
	putexcel E2 = "n"
	putexcel F2 = "Prevalence/Mean"
	putexcel G2 = "SD"
	putexcel H2 = "ITT"
	putexcel I2 = "CI 95%"
	
	putexcel (I2:J2), merge hcenter
	
	* add var labels
	putexcel A3 = "Diarrhea prevalence"
	* add reg table
	putexcel B3 = matrix(results), nformat(number_d2)

	* end of table *
	
	
	**** Length for age

	* Load dataset created by igrowup_standard command
	* use "98_igrowup_output\vea_anthro_z_st.dta", clear
	use "${hp_anthro_z_constructed}", clear
		
* Primary outcome
global primary _zlen

* table
mat results = J(`: word count $primary', 9, .)
forvalues i = 1/`: word count $primary' {
	local var: word `i' of $primary
	reg `var' treatment_status selected_child_sex_new selected_age_years i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_3_hp.xlsx", modify
	
	* add var labels
	putexcel A4 = "Length-for-age Z-score"
	* add reg table
	putexcel B4= matrix(results), nformat(number_d2)
	
	* end of table *
	
	
	**** Institution
	
	use "${hp_vl_constructed}", clear // Load VL constructed data	
* Primary outcomes 
global primary ME_institutions
		
* add labels/headers via putexcel directly
mat results = J(`: word count $primary', 9, .)
forvalues i = 1/`: word count $primary' {
	local var: word `i' of $primary
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_3_hp.xlsx", modify

	* add var labels
	putexcel A5 = "WASH institutions index"
	* add reg table
	putexcel B5 = matrix(results), nformat(number_d2)
	
		* Final formatting
	putexcel B3:B5, overwritefmt nformat(number)
	putexcel E3:E5, overwritefmt nformat(number)
	putexcel C3, overwritefmt nformat(percent)
	putexcel F3, overwritefmt nformat(percent)
	
	
	* end of table *
	
	
* end of dofile *
