	/*******************************************************************************

	Title: 			table_4_health_paper.do
	Author(s): 		Caleb Jeremie Dohou & Luca Stanus Ghib
	Description: 	This dofile produces combined table for secondary outcomes table. Table 4. Intervention effects on secondary outcomes related to water, sanitation, and hygiene
	Input: 	"${hp_hh_constructed}", "${hp_so_hh_level}", "${hp_wp_constructed}" "${hp_hhw_constructed}", "${hp_anthro_z_constructed}" "${hp_hh_child_roster}", see global defined in Project_MasterDofile.do
	Output:	"${hp_tables}/table_4_hp.xlsx"

	*******************************************************************************/

	******** load hh-level dataset
	use "${hp_hh_constructed}", clear


	******* Lancet table with secondary outcomes


	global secondary_hh watersourceimproved improvedsanitation HH_water_gov_perception watertriptotalminsalltrips_ihs wateruse_cost water_exp_wkly hygiene_behaviour_index_new 

	** add labels/headers via putexcel directly
	mat results = J(`: word count $secondary_hh', 9, .)
	forvalues i = 1/`: word count $secondary_hh' {
		local var: word `i' of $secondary_hh
		reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
		matrix row1=r(table) 
		matrix results[`i',7]=row1[1,1]
		matrix results[`i',8]=row1[5,1]
		matrix results[`i',9]=row1[6,1]
	 sum `var' if e(sample) & treatment_status == 0
		matrix results[`i',1]=r(N)
		matrix results[`i',2]=r(mean)
		matrix results[`i',3]=r(sd)
	sum `var' if e(sample) & treatment_status == 1
		matrix results[`i',4]=r(N)
		matrix results[`i',5]=r(mean)
		matrix results[`i',6]=r(sd)
	}
		matrix list results
		putexcel set "${hp_tables}/table_4_hp.xlsx", replace 

		* add headers
		putexcel A2 = ("Outcomes")
		putexcel B1 = ("Control")
		putexcel (B1:D1), merge hcenter
		putexcel B2 = "n"
		putexcel C2 = "Prevalence/Mean"
		putexcel D2 = "SD"
		putexcel E1 = "Intervention"
		putexcel (E1:G1), merge hcenter
		putexcel E2 = "n"
		putexcel F2 = "Prevalence/Mean"
		putexcel G2 = "SD"
		putexcel H2 = "ITT"
		putexcel I2 = "CI 95%"
		putexcel (I2:J2), merge hcenter
		* add var labels
		putexcel A3 = "Improved water source"
		putexcel A4 = "Improved sanitation"
		putexcel A5 = "Water gov. perception index"
		putexcel A6 = "Time spent collecting water (IHS)"
		putexcel A7 = "HH pay for water (1=yes)"
		putexcel A8 = "Water expenditure (weekly, CDF)"
		putexcel A9 = "Hygiene and behaviour index"

		* add reg table
		putexcel B3 = matrix(results), nformat(number_d2) 
		
		* end of table *
		
		
	* Observed hanwashing table
	use "${hp_so_hh_level}", clear

	global secondary so_hw_share so_hw_soap_ash_share 

	** add labels/headers via putexcel directly
	mat results = J(`: word count $secondary', 9, .)
	forvalues i = 1/`: word count $secondary' {
		local var: word `i' of $secondary
		reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
		matrix row1=r(table) 
		matrix results[`i',7]=row1[1,1]
		matrix results[`i',8]=row1[5,1]
		matrix results[`i',9]=row1[6,1]
	 sum `var' if e(sample) & treatment_status == 0
		matrix results[`i',1]=r(N)
		matrix results[`i',2]=r(mean)
		matrix results[`i',3]=r(sd)
	sum `var' if e(sample) & treatment_status == 1
		matrix results[`i',4]=r(N)
		matrix results[`i',5]=r(mean)
		matrix results[`i',6]=r(sd)
	}
		matrix list results
		putexcel set "${hp_tables}/table_4_hp.xlsx", modify 

		* add headers
		putexcel A2 = "Outcomes"
		putexcel B1 = "Control"
		putexcel (B1:D1), merge hcenter
		putexcel B2 = "n"
		putexcel C2 = "Prevalence/Mean"
		putexcel D2 = "SD"
		putexcel E1 = "Intervention"
		putexcel (E1:G1), merge hcenter
		putexcel E2 = "n"
		putexcel F2 = "Prevalence/Mean"
		putexcel G2 = "SD"
		putexcel H2 = "ITT"
		putexcel I2 = "CI 95%"
		putexcel (I2:J2), merge hcenter
		* add var labels
		putexcel A10 = "Handwashing action"
		putexcel A11 = "Handwashing with soap/ash"
		* add reg table
		putexcel B10 = matrix(results), nformat(number_d2) 
		
			* end of table *
	

******** load raw dataset
use "${hp_wp_constructed}", clear	

global secondary wp_has_water water_risk_logmpn

** add labels/headers via putexcel directly
mat results = J(`: word count $secondary', 9, .)
forvalues i = 1/`: word count $secondary' {
	local var: word `i' of $secondary
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_4_hp.xlsx", modify

	* add var labels
	putexcel A12 = "Water point has water"
	putexcel A13 = "WP Coliforms log10 MPN/100mL" 
	* add reg table
	putexcel B12 = matrix(results), nformat(number_d2)
	
		* end of table *


******** load raw dataset
use "${hp_hhw_constructed}", clear

***** Water risk analysis using the continuous variables water_risk_mpn water_risk_logmpn
global secondary_ecoli water_risk_logmpn

** add labels/headers via putexcel directly
mat results = J(`: word count $secondary_ecoli', 9, .)
forvalues i = 1/`: word count $secondary_ecoli' {
	local var: word `i' of $secondary_ecoli
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_4_hp.xlsx", modify
	
	* add var labels
	putexcel A14 = "HH Coliforms log10 MPN/100mL" 
	* add reg table
	putexcel B14 = matrix(results), nformat(number_d2)
	
	* end of table *


	* Anthro Secondary outcome
	use "${hp_anthro_z_constructed}", clear	

* Secondary outcome
global secondary _zwei _zwfl

* table
mat results = J(`: word count $secondary', 9, .)
forvalues i = 1/`: word count $secondary' {
	local var: word `i' of $secondary
	reg `var' treatment_status selected_child_sex_new selected_age_years i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_4_hp.xlsx", modify 
	
	* add var labels
	putexcel A15 = "Weight-for-age Z-score"
	putexcel A16 = "Weight-for-length Z-score"
	* add reg table
	putexcel B15 = matrix(results), nformat(number_d2)
	
	* end of table *
	
******** load hh-level dataset
use "${hp_hh_constructed}", clear


global secondary_hh self_esteem_index psych_well_being 

** add labels/headers via putexcel directly
mat results = J(`: word count $secondary_hh', 9, .)
forvalues i = 1/`: word count $secondary_hh' {
	local var: word `i' of $secondary_hh
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_4_hp.xlsx", modify 

	* add headers
	putexcel A2 = "Outcomes"
	putexcel B1 = "Control"
	putexcel (B1:D1), merge hcenter
	putexcel B2 = "n"
	putexcel C2 = "Prevalance/Mean"
	putexcel D2 = "SD"
	putexcel E1 = "Intervention"
	putexcel (E1:G1), merge hcenter
	putexcel E2 = "n"
	putexcel F2 = "Prevalence/Mean"
	putexcel G2 = "SD"
	putexcel H2 = "ITT"
	putexcel I2 = "CI 95%"
	putexcel (I2:J2), merge hcenter
	* add var labels
	putexcel A17 = "Life satisfaction & self-esteem index"
	putexcel A18 = "Psychological well-being index"
	* add reg table
	putexcel B17 = matrix(results), nformat(number_d2) 
	
	* end of table *
	
******** load child-level dataset
use "${hp_hh_child_roster}", clear
		
	**** Lancet school attendance
global secondary child_6to18_attendsch_lwks

** add labels/headers via putexcel directly
mat results = J(`: word count $secondary', 9, .)
forvalues i = 1/`: word count $secondary' {
	local var: word `i' of $secondary
	reg `var' treatment_status i.province#cluster_strata i.week winter_holiday, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_4_hp.xlsx", modify 

	* add headers
	putexcel A2 = "Outcomes"
	putexcel B1 = "Control"
	putexcel (B1:D1), merge hcenter
	putexcel B2 = "n"
	putexcel C2 = "Prevalence/Mean"
	putexcel D2 = "SD"
	putexcel E1 = "Intervention"
	putexcel (E1:G1), merge hcenter
	putexcel E2 = "n"
	putexcel F2 = "Prevalence/Mean"
	putexcel G2 = "SD"
	putexcel H2 = "ITT"
	putexcel I2 = "CI 95%"
	putexcel (I2:J2), merge hcenter
	* add var labels
	putexcel A19 = "School attendance (days past week)"
	* add reg table
	putexcel B19 = matrix(results), nformat(number_d2) 
	
			* Final formatting
	putexcel B3:B19, overwritefmt nformat(number)
	putexcel E3:E19, overwritefmt nformat(number)
	
	putexcel C3:C4, overwritefmt nformat(percent)
	putexcel F3:F4, overwritefmt nformat(percent)
	putexcel C7, overwritefmt nformat(percent)	
	putexcel F7, overwritefmt nformat(percent)
	putexcel C10:C12, overwritefmt nformat(percent)
	putexcel F10:F12, overwritefmt nformat(percent)
	
	* Deleted SDs for binary variables
	putexcel D3:D4 = ""
	putexcel G3:G4 = ""
	putexcel D7 = ""	
	putexcel G7 = ""
	putexcel D10:D12 = ""
	putexcel G10:G12 = ""
	
	*  Round cells for Water expenditure (weekly, CDF)
	putexcel C8:J8, overwritefmt nformat(number)
	
	
		* end of table *
		
	
* end of dofile *
