/*******************************************************************************

Title: 			table_s1_health_paper.do
Author(s): 		Caleb Jeremie Dohou
Description: 	This dofile produces a table breaking down randomization strata and figures. It is reference in the supplementary Information file as Table S1. Randomization strata.
Input: 	"${assignment}", "${assignmentsk}", see global defined in Project_MasterDofile.do
Output:	"${hp_tables}/table_s1_hp.xlsx"

*******************************************************************************/

	
*** Load initial randomization output data for all provinces
use "${rando_fulldata}", clear

** Labeling variables
label var cluster_strata "Stratum"


bysort province : tab cluster_strata cluster_size, mi

*** Create variable capturing number of villages per cluster
gen village_per_cluster = ""

** Kongo Central Province
replace village_per_cluster = "1-2" if province == 1 & cluster_strata == 1
replace village_per_cluster = "3-4" if province == 1 & cluster_strata == 2
replace village_per_cluster = "5,7" if province == 1 & cluster_strata == 3

** Kasai Province
replace village_per_cluster = "1-2" if province == 2 & cluster_strata == 1
replace village_per_cluster = "3-5" if province == 2 & cluster_strata == 2
replace village_per_cluster = "10,12" if province == 2 & cluster_strata == 3

** Kasai Central Province
replace village_per_cluster = "1-2" if province == 3 & cluster_strata == 1
replace village_per_cluster = "3-4" if province == 3 & cluster_strata == 2
replace village_per_cluster = "6-7" if province == 3 & cluster_strata == 3

** Kasai Central Province
replace village_per_cluster = "1-2" if province == 5 & cluster_strata == 1
replace village_per_cluster = "4-8,10" if province == 5 & cluster_strata == 2
replace village_per_cluster = "12,14" if province == 5 & cluster_strata == 3


tab village_per_cluster, mi
label var village_per_cluster "Villages-per-cluster"

*** Create variable capturing number of villages per stratum within cluster categories
bysort province cluster_strata village_per_cluster: gen village_per_stratum = _N
tab village_per_stratum, mi
label var village_per_stratum "Total villages in stratum"

*** Create variable capturing number of villages per stratum in treatment within cluster categories
bysort province cluster_strata village_per_cluster: egen T_village_per_stratum = total(treatment_status)
tab T_village_per_stratum, mi

label var T_village_per_stratum "Intervention villages in stratum"

*** Create variable capturing number of villages per stratum  in control within cluster categories
gen control_status = (treatment_status == 0)
bysort province cluster_strata village_per_cluster: egen C_village_per_stratum = total(control_status)
tab C_village_per_stratum, mi

label var C_village_per_stratum "Control villages in stratum"



*** Create variable capturing number of clusters per stratum within cluster categories
egen cluster_tag = tag(province cluster_strata village_per_cluster group)
bysort province cluster_strata village_per_cluster: egen cluster_per_stratum = total(cluster_tag)
tab cluster_per_stratum, mi
label var cluster_per_stratum "Total clusters in stratum"

*** Create variable capturing number of clusters per stratum in treatment within cluster categories
egen T_cluster_tag = tag(province cluster_strata village_per_cluster group) if treatment_status == 1
bysort province cluster_strata village_per_cluster: egen T_cluster_per_stratum = total(T_cluster_tag)
tab T_cluster_per_stratum, mi
label var T_cluster_per_stratum "Intervention clusters in stratum"

*** Create variable capturing number of clusters per stratum  in control within cluster categories
egen C_cluster_tag = tag(province cluster_strata village_per_cluster group) if treatment_status == 0
bysort province cluster_strata village_per_cluster: egen C_cluster_per_stratum = total(C_cluster_tag)
tab C_cluster_per_stratum, mi

label var C_cluster_per_stratum "Control clusters in stratum"


*** Collapsing data on the cluster villages per cluster categories level
duplicates drop province cluster_strata village_per_cluster, force

keep province cluster_strata village_per_cluster village_per_stratum T_village_per_stratum C_village_per_stratum cluster_per_stratum T_cluster_per_stratum C_cluster_per_stratum

*** Turning province variable into string
decode province, gen(prov)
order prov
drop province
rename prov province


*** Computing total figures for each relevant column
preserve
ds village_per_stratum T_village_per_stratum C_village_per_stratum cluster_per_stratum T_cluster_per_stratum C_cluster_per_stratum
collapse (sum)`r(varlist)'

tempfile temp_collapse
save "`temp_collapse'", replace
restore
append using "`temp_collapse'"

replace province = "Total" if _n == _N

*** Formatting province column
replace province = "" if _n == 2 | _n == 3 | _n == 5 | _n == 6 | _n == 8 | _n == 9 | _n == 11 | _n == 12

*** Exporting Randomization Strata table 
export excel using "${hp_tables}/table_s1_hp.xlsx", firstrow(varlabels) replace
	
* end of dofile *
