/*******************************************************************************

Title: 			table_s2_health_paper.do
Author(s): 		Caleb Jeremie Dohou & Luca Stanus Ghib
Description: 	This dofile produces combined table for institutions and sub-components. Table S2. Intervention effects on WASH institutions index and index sub-components
Input: 	"${hp_vl_constructed}", see global defined in Project_MasterDofile.do
Output:	"${hp_tables}/table_s2_hp.xlsx"

*******************************************************************************/
	
	
**** WASH Institution
	
	use "${hp_vl_constructed}", clear // Load VL constructed data
	
* Primary outcomes with index subcomponents
global primary ME_institutions wa_comm wash_comm_meetings_r wash_exp_water_ihs health_track defec_track
		
mat results = J(`: word count $primary', 9, .)
forvalues i = 1/`: word count $primary' {
	local var: word `i' of $primary
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_s2_hp.xlsx", replace

	* add headers
    putexcel A2 = "Outcomes"
	putexcel B1 = "Control"
	putexcel (B1:D1), merge hcenter
	putexcel B2 = "n"
	putexcel C2 = "Prevalence/Mean"
	putexcel D2 = "SD"
	putexcel E1 = "Intervention"
	putexcel (E1:G1), merge hcenter
	putexcel E2 = "n"
	putexcel F2 = "Prevalence/Mean"
	putexcel G2 = "SD"
	putexcel H2 = "ITT"
	putexcel I1 = "CI 95%"
	putexcel I2 = "Lower Bound"
	putexcel J2 = "Upper Bound"
	putexcel (I1:J1), merge hcenter
	* add var labels
	putexcel A3 = "WASH institutions index"
	putexcel A4 = "Committee (y/n)"
	putexcel A5 = "Committee mtg freq"
	putexcel A6 = "WASH expenditures (CDF per month, IHS)"
	putexcel A7 = "Track health (y/n)"
	putexcel A8 = "Track sanitation (y/n)"
	* add reg table
	putexcel B3 = matrix(results), nformat(number_d2)
	
	* Final formatting
	putexcel B3:B8, overwritefmt nformat(number)
	putexcel E3:E8, overwritefmt nformat(number)
	
	putexcel C4, overwritefmt nformat(percent)
	putexcel F4, overwritefmt nformat(percent)
	putexcel C7:C8, overwritefmt nformat(percent)
	putexcel F7:F8, overwritefmt nformat(percent)
	
	*  Round cells for Water expenditure (weekly, CDF)
	putexcel C6:J6, overwritefmt nformat(number)
	
	* Deleted SDs for binary variables
	putexcel D4 = ""
	putexcel G4 = ""
	putexcel D7:D8 = ""	
	putexcel G7:G8 = ""

	
	* end of table *
	
* end of dofile *
