/*******************************************************************************

Title: 			table_s3_health_paper.do
Author(s): 		Caleb Jeremie Dohou & Luca Stanus Ghib
Description: 	This dofile produces combined table for secondary outcomes table. Table S3. Intervention effects on all secondary outcomes, including index sub-components.
Input: 	"${hp_hh_constructed}", "${hp_so_hh_level}", "${hp_wp_constructed}", "${hp_hhw_constructed}", "${hp_anthro_z_constructed}", "${hp_hh_child_roster}", see global defined in Project_MasterDofile.do
Output:	"${hp_tables}/table_s3_hp.xlsx", 

*******************************************************************************/

********************************************************************************
********************************************************************************

******** load hh-level dataset
use "${hp_hh_constructed}", clear


******* Table S3. Intervention effects on all secondary outcomes, including index sub-components

global secondary_hhindex watersourceimproved improvedsanitation HH_water_gov_perception comm_select_fairly fairtreat_bycomm comm_money_manage comm_response_breakd trust_comm_response satisfac_water_access


** add labels/headers via putexcel directly
mat results = J(`: word count $secondary_hhindex', 9, .)
forvalues i = 1/`: word count $secondary_hhindex' {
	local var: word `i' of $secondary_hhindex
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_s3_hp.xlsx", replace

	* add headers
	putexcel A2 = "Outcomes"
	putexcel B1 = "Control"
	putexcel (B1:D1), merge hcenter
	putexcel B2 = "n"
	putexcel C2 = "Prevalance/Mean"
	putexcel D2 = "SD"
	putexcel E1 = "Intervention"
	putexcel (E1:G1), merge hcenter
	putexcel E2 = "n"
	putexcel F2 = "Prevalance/Mean"
	putexcel G2 = "SD"
	putexcel H2 = "ITT"
	putexcel I2 = "CI 95%"
	putexcel (I2:J2), merge hcenter
	
	* add var labels
	putexcel A3 = "Improved water source"
	putexcel A4 = "Improved sanitation"
	putexcel A5 = "Water Governance perception index"
	putexcel A6 = "Committee selected fairly"
	putexcel A7 = "Committee treats community fairly"
	putexcel A8 = "Committee manages money well"
	putexcel A9 = "Comm responds breakdown well"
	putexcel A10 = "Confidence committee will solve reported issue"
	putexcel A11 = "Satisfaction with water access (1-5)"
	
	* add reg table
	putexcel B3 = matrix(results), nformat(number_d2) 
	
	* end of table *

	
global secondary_hh watertriptotalminsalltrips_ihs wateruse_cost water_exp_wkly hygiene_behaviour_index_new hw_score open_defecation used_soap_ash latrine_clean_2wks clean_covered_pot water_treated

** add labels/headers via putexcel directly
mat results = J(`: word count $secondary_hh', 9, .)
forvalues i = 1/`: word count $secondary_hh' {
	local var: word `i' of $secondary_hh
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_s3_hp.xlsx", modify

	* add headers
	putexcel A2 = "Outcomes"
	putexcel B1 = "Control"
	putexcel (B1:D1), merge hcenter
	putexcel B2 = "n"
	putexcel C2 = "Prevalance/Mean"
	putexcel D2 = "SD"
	putexcel E1 = "Intervention"
	putexcel (E1:G1), merge hcenter
	putexcel E2 = "n"
	putexcel F2 = "Prevalance/Mean"
	putexcel G2 = "SD"
	putexcel H2 = "IIT"
	putexcel I2 = "CI 95%"
	putexcel (I2:J2), merge hcenter
	* add var labels
	putexcel A13 = "Time spent collecting water (IHS)"
	putexcel A14 = "HHs pay for water (Dummy)"
    putexcel A15 = "Water use expenditure (weekly)"
	putexcel A16 = "Hygiene and behaviour index"
	putexcel A17 = "Handwashing score (0-10)"
	putexcel A18 = "Open defecation (%)"
	putexcel A19 = "Self-reported handwashing with soap/ash (%)"
	putexcel A20 = "Frequency of latrine cleaning over past 2 weeks"
	putexcel A21 = "Water in pot is clean and covered (%)"
	putexcel A22 = "Water treated for consumption, any method (%)"
	* add reg table
	putexcel B13 = matrix(results), nformat(number_d2)
	
	* end of table *
	


* Observed hanwashing table
use "${hp_so_hh_level}", clear

global secondary so_hw_share so_hw_soap_ash_share

** add labels/headers via putexcel directly
mat results = J(`: word count $secondary', 9, .)
forvalues i = 1/`: word count $secondary' {
	local var: word `i' of $secondary
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_s3_hp.xlsx", modify

	* add headers
	putexcel A2 = "Outcomes"
	putexcel B1 = "Control"
	putexcel (B1:D1), merge hcenter
	putexcel B2 = "n"
	putexcel C2 = "Prevalance/Mean"
	putexcel D2 = "SD"
	putexcel E1 = "Intervention"
	putexcel (E1:G1), merge hcenter
	putexcel E2 = "n"
	putexcel F2 = "Prevalance/Mean"
	putexcel G2 = "SD"
	putexcel H2 = "ITT"
	putexcel I2 = "CI 95%"
	putexcel (I2:J2), merge hcenter
	* add var labels
	putexcel A24 = "Handwashing action"
	putexcel A25 = "Handwashing with soap/ash"
	* add reg table
	putexcel B24 = matrix(results), nformat(number_d2)
	
		* end of table *


******** load raw dataset
use "${hp_wp_constructed}", clear	

global secondary wp_has_water

** add labels/headers via putexcel directly
mat results = J(`: word count $secondary', 9, .)
forvalues i = 1/`: word count $secondary' {
	local var: word `i' of $secondary
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_s3_hp.xlsx", modify

	* add var labels
	putexcel A26 = "Water point has water" 
	
	* add reg table
	putexcel B26 = matrix(results), nformat(number_d2)
	
		* end of table *


	******** load raw dataset
use "${hp_wp_constructed}", clear	
	
	***** Water risk analysis using the continuous variables water_risk_mpn water_risk_logmpn
global secondary_ecoli water_risk_mpn water_risk_logmpn

** add labels/headers via putexcel directly
mat results = J(`: word count $secondary_ecoli', 9, .)
forvalues i = 1/`: word count $secondary_ecoli' {
	local var: word `i' of $secondary_ecoli
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_s3_hp.xlsx", modify
	
	* add var labels
	putexcel A27 = "WP Coliforms MPN/100mL"
	putexcel A28 = "WP Coliforms log10 MPN/100mL"
	
	* add reg table
	putexcel B27 = matrix(results), nformat(number_d2)
	
	* end of table *


******** load raw dataset
use "${hp_hhw_constructed}", clear

***** Water risk analysis using the continuous variables water_risk_mpn water_risk_logmpn
global secondary_ecoli water_risk_mpn water_risk_logmpn

** add labels/headers via putexcel directly
mat results = J(`: word count $secondary_ecoli', 9, .)
forvalues i = 1/`: word count $secondary_ecoli' {
	local var: word `i' of $secondary_ecoli
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_s3_hp.xlsx", modify
	
	* add var labels
	putexcel A29 = "HH Coliforms MPN/100mL"
	putexcel A30 = "HH Coliforms log10 MPN/100mL"
	
	* add reg table
	putexcel B29 = matrix(results), nformat(number_d2)
	
	* end of table *	
	


******** load raw dataset
use "${hp_anthro_z_constructed}", clear

* Primary outcome
global secondary _zwei _zwfl

* table
mat results = J(`: word count $secondary', 9, .)
forvalues i = 1/`: word count $secondary' {
	local var: word `i' of $secondary
	reg `var' treatment_status selected_child_sex_new selected_age_years i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_s3_hp.xlsx", modify
	
	* add var labels
	putexcel A32 = "Weight for age"
	putexcel A33 = "Weight for length"
	* add reg table
	putexcel B32 = matrix(results), nformat(number_d2)
	
	* end of table *


******** load hh-level dataset
use "${hp_hh_constructed}", clear
	
global secondary_hhindex self_esteem_index wvs rosenberg_1st rosenberg_2nd rosenberg_3rd_reverse rosenberg_4th rosenberg_5th_reserve rosenberg_6th rosenberg_7th rosenberg_8th_reverse rosenberg_9th_reverse rosenberg_10th_reverse

** add labels/headers via putexcel directly
mat results = J(`: word count $secondary_hhindex', 9, .)
forvalues i = 1/`: word count $secondary_hhindex' {
	local var: word `i' of $secondary_hhindex
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_s3_hp.xlsx", modify

	* add headers
	putexcel A2 = "Outcomes"
	putexcel B1 = "Control"
	putexcel (B1:D1), merge hcenter
	putexcel B2 = "n"
	putexcel C2 = "Prevalance/Mean"
	putexcel D2 = "SD"
	putexcel E1 = "Intervention"
	putexcel (E1:G1), merge hcenter
	putexcel E2 = "n"
	putexcel F2 = "Prevalance/Mean"
	putexcel G2 = "SD"
	putexcel H2 = "ITT"
	putexcel I2 = "CI 95%"
	putexcel (I2:J2), merge hcenter
	* add var labels
	putexcel A34 = "Life satisfaction & self-esteem index"
	putexcel A35 = "Life satisfaction (WVS)"
	putexcel A36 = "Feel I am person of worth (Rosenberg)"
	putexcel A37 = "Feel that I have good qualities (Rosenberg)"
	putexcel A38 = "Inclined to feel I am a failure (Rosenberg)"
	putexcel A39 = "Able to do things as well as oth people (Rosenberg)"
	putexcel A40 = "Feel have not much to be proud of (Rosenberg)"
	putexcel A41 = "Take a positive attitude towards self (Rosenberg)"
	putexcel A42 = "I am satisfied with myself (Rosenberg)"
	putexcel A43 = "Wish could have more respect for myself (Rosenberg)"
	putexcel A44 = "Certainly feel useless at times (Rosenberg)"
	putexcel A45 = "At times think I am no good at all (Rosenberg)"
	* add reg table
	putexcel B34 = matrix(results), nformat(number_d2)
	
	* end of table *
	
	
global secondary_hhindex psych_well_being who_1st who_2nd who_3rd who_4th who_5th cohen_1st_reverse cohen_2nd cohen_3rd cohen_4th_reverse

** add labels/headers via putexcel directly
mat results = J(`: word count $secondary_hhindex', 9, .)
forvalues i = 1/`: word count $secondary_hhindex' {
	local var: word `i' of $secondary_hhindex
	reg `var' treatment_status i.province#cluster_strata, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_s3_hp.xlsx", modify

	* add headers
	putexcel A2 = "Outcomes"
	putexcel B1 = "Control"
	putexcel (B1:D1), merge hcenter
	putexcel B2 = "n"
	putexcel C2 = "Prevalance/Mean"
	putexcel D2 = "SD"
	putexcel E1 = "Intervention"
	putexcel (E1:G1), merge hcenter
	putexcel E2 = "n"
	putexcel F2 = "Prevalance/Mean"
	putexcel G2 = "SD"
	putexcel H2 = "ITT"
	putexcel I2 = "CI 95%"
	putexcel (I2:J2), merge hcenter
	* add var labels
	putexcel A47 = "Psychological well-being index"
	putexcel A48 = "Felt cheerful last 2 weeks (WHO)"
	putexcel A49 = "Felt calm & relaxed last 2 weeks (WHO)"
	putexcel A50 = "Felt active & vigorous last 2 weeks (WHO)"
	putexcel A51 = "Woke up fresh & rested last 2 weeks (WHO)"
	putexcel A52 = "Daily life filled with things that interest last 2 weeks (WHO)"
	putexcel A53 = "Felt unable to control important things last month (Cohen)"
	putexcel A54 = "Felt confident about ability to handle personal problems last month (Cohen)"
	putexcel A55 = "Felt confident things were going your way last month (Cohen)"
	putexcel A56 = "Felt difficulties were piling up could not overcome them last month (Cohen)"
	* add reg table
	putexcel B47 = matrix(results), nformat(number_d2)
	
	* end of table *

	
******** load child-level dataset
use "${hp_hh_child_roster}", clear
		
	**** Lancet school attendance
global secondary child_6to18_attendsch_lwks

** add labels/headers via putexcel directly
mat results = J(`: word count $secondary', 9, .)
forvalues i = 1/`: word count $secondary' {
	local var: word `i' of $secondary
	reg `var' treatment_status i.province#cluster_strata i.week winter_holiday, vce(cluster group)
	matrix row1=r(table) 
	matrix results[`i',7]=row1[1,1]
	matrix results[`i',8]=row1[5,1]
	matrix results[`i',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[`i',1]=r(N)
	matrix results[`i',2]=r(mean)
	matrix results[`i',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[`i',4]=r(N)
	matrix results[`i',5]=r(mean)
	matrix results[`i',6]=r(sd)
}
	matrix list results
	putexcel set "${hp_tables}/table_s3_hp.xlsx", modify

	* add headers
	putexcel A2 = "Outcomes"
	putexcel B1 = "Control"
	putexcel (B1:D1), merge hcenter
	putexcel B2 = "n"
	putexcel C2 = "Prevalance/Mean"
	putexcel D2 = "SD"
	putexcel E1 = "Intervention"
	putexcel (E1:G1), merge hcenter
	putexcel E2 = "n"
	putexcel F2 = "Prevalance/Mean"
	putexcel G2 = "SD"
	putexcel H2 = "ITT"
	putexcel I2 = "CI 95%"
	putexcel (I2:J2), merge hcenter
	* add var labels
	putexcel A58 = "School attendance (days past week)"
	* add reg table
	putexcel B58 = matrix(results), nformat(number_d2)
	
	
	* Final formatting
	putexcel B3:B58, overwritefmt nformat(number)
	putexcel E3:E58, overwritefmt nformat(number)
	
	putexcel C3:C4, overwritefmt nformat(percent)
	putexcel F3:F4, overwritefmt nformat(percent)
	
	putexcel C14, overwritefmt nformat(percent)
	putexcel F14, overwritefmt nformat(percent)
	
	putexcel C18:C19, overwritefmt nformat(percent)
	putexcel F18:F19, overwritefmt nformat(percent)
	
	putexcel C21:C22, overwritefmt nformat(percent)
	putexcel F21:F22, overwritefmt nformat(percent)
	
	putexcel C24:C26, overwritefmt nformat(percent)
	putexcel F24:F26, overwritefmt nformat(percent)
	
	* Deleted SDs for binary variables
	putexcel D3:D4 = ""
	putexcel G3:G4 = ""
	putexcel D14 = ""	
	putexcel G14 = ""
	putexcel D18:D19 = ""
	putexcel G18:G19 = ""
	putexcel D21:D22 = ""
	putexcel G21:G22 = ""
	putexcel D24:D26 = ""
	putexcel G24:G26 = ""
	
	*  Round cells for Water expenditure (weekly, CDF)
	putexcel C15:J15, overwritefmt nformat(number)
	
		* end of table *
	
	
* end of dofile *
