/*******************************************************************************

Title: 			table_s4_health_paper.do
Author(s): 		Caleb Jeremie Dohou
Description: 	This dofile produces Table s4: Province subgroup analysis.Table S4. Intervention effects on all primary outcomes, by province (pre-specified)
Input: 	"${hp_hh_child_roster}", "${hp_anthro_z_constructed}", "${hp_vl_constructed}", see global defined in Project_MasterDofile.do
Output:	"${hp_tables}/table_s4_hp.xlsx"

*******************************************************************************/	
	
	
********************************************************************************
* Province Subgroup Analysis
********************************************************************************


******** load child-level dataset
use "${hp_hh_child_roster}", clear

	***** Diarrhea

* Primary outcomes 
global primary diarrhea_outcome

mat results = J(`: word count $primary'*4, 9, .)
forvalues i = 1/`: word count $primary' {
 forvalues j=1/4{
	local var: word `i' of $primary
	reg `var' treatment_status child_sex child_age_years i.cluster_strata if province==`j', vce(cluster group)
	matrix row1=r(table) 
	matrix results[(`i'-1)*4+`j',7]=row1[1,1]
	matrix results[(`i'-1)*4+`j',8]=row1[5,1]
	matrix results[(`i'-1)*4+`j',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[(`i'-1)*4+`j',1]=r(N)
	matrix results[(`i'-1)*4+`j',2]=r(mean)
	matrix results[(`i'-1)*4+`j',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[(`i'-1)*4+`j',4]=r(N)
	matrix results[(`i'-1)*4+`j',5]=r(mean)
	matrix results[(`i'-1)*4+`j',6]=r(sd)
	*matrix results[`i',1]="`var'"
	}
}
	matrix list results
	putexcel set "${hp_tables}/table_s4_hp.xlsx", replace
		
	putexcel C3 = matrix(results), nformat(number_d2)
	* add headers
	putexcel A2 = "Outcomes"
	putexcel B2 = "Province"
	putexcel C1 = "Control"
	putexcel C2 = "n"
	putexcel D2 = "Prevalence/Mean"
	putexcel E2 = "SD"
	putexcel (C1:E1), merge hcenter
	putexcel F1 = "Intervention"
	putexcel F2 = "n"
	putexcel G2 = "Prevalence/Mean"
	putexcel H2 = "SD"
	putexcel (E1:G1), merge hcenter
	putexcel I2 = "ITT"
	putexcel J1 = "CI 95%"
	putexcel J2 = "Lower Bound"
	putexcel K2 = "Upper Bound"
	putexcel (J1:K1), merge hcenter
	* add var labels
	putexcel A3 = "Diarrhea prevalence"

	* add province labels
	putexcel B3 = "Kongo Central"
	putexcel B4 = "Kasai"
	putexcel B5 = "Kasai Central"
	putexcel B6 = "South Kivu"
	
* end of subgroup table *


**** Length for age
	use "${hp_anthro_z_constructed}", clear // Load Anthro constructed data

* Primary outcome
global primary _zlen

mat results = J(`: word count $primary'*4, 9, .)
forvalues i = 1/`: word count $primary' {
 forvalues j=1/4{
	local var: word `i' of $primary
	reg `var' treatment_status selected_child_sex_new selected_age_years i.cluster_strata if province==`j', vce(cluster group)
	matrix row1=r(table) 
	matrix results[(`i'-1)*4+`j',7]=row1[1,1]
	matrix results[(`i'-1)*4+`j',8]=row1[5,1]
	matrix results[(`i'-1)*4+`j',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[(`i'-1)*4+`j',1]=r(N)
	matrix results[(`i'-1)*4+`j',2]=r(mean)
	matrix results[(`i'-1)*4+`j',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[(`i'-1)*4+`j',4]=r(N)
	matrix results[(`i'-1)*4+`j',5]=r(mean)
	matrix results[(`i'-1)*4+`j',6]=r(sd)
	}
}
	matrix list results
	putexcel set "${hp_tables}/table_s4_hp.xlsx", modify
		
	putexcel C8 = matrix(results), nformat(number_d2)

	* add var labels
	putexcel A8 = "Length-for-age Z-score"

	* add province labels
	putexcel B8 = "Kongo Central"
	putexcel B9 = "Kasai"
	putexcel B10 = "Kasai Central"
	putexcel B11 = "South Kivu"
	
* end of subgroup table *
	
	
**** WASH institutions index
	use "${hp_vl_constructed}", clear // Load VL constructed data

* Primary outcomes 
global primary ME_institutions

mat results = J(`: word count $primary'*4, 9, .)
forvalues i = 1/`: word count $primary' {
 forvalues j=1/4{
	local var: word `i' of $primary
	reg `var' treatment_status i.cluster_strata if province==`j', vce(cluster group)
	matrix row1=r(table) 
	matrix results[(`i'-1)*4+`j',7]=row1[1,1]
	matrix results[(`i'-1)*4+`j',8]=row1[5,1]
	matrix results[(`i'-1)*4+`j',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[(`i'-1)*4+`j',1]=r(N)
	matrix results[(`i'-1)*4+`j',2]=r(mean)
	matrix results[(`i'-1)*4+`j',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[(`i'-1)*4+`j',4]=r(N)
	matrix results[(`i'-1)*4+`j',5]=r(mean)
	matrix results[(`i'-1)*4+`j',6]=r(sd)
	*matrix results[`i',1]="`var'"
	}
}
	matrix list results
	putexcel set "${hp_tables}/table_s4_hp.xlsx", modify
		
	putexcel C13 = matrix(results), nformat(number_d2)

	* add var labels
	putexcel A13 = "WASH institutions index"

	* add province labels
	putexcel B13 = "Kongo Central"
	putexcel B14 = "Kasai"
	putexcel B15 = "Kasai Central"
	putexcel B16 = "South Kivu"	
	
	* Final formatting
	putexcel C3:C16, overwritefmt nformat(number)
	putexcel F3:F16, overwritefmt nformat(number)
	
	putexcel D3:D6, overwritefmt nformat(percent)
	putexcel G3:G6, overwritefmt nformat(percent)
	
	* Deleted SDs for binary variables
	putexcel E3:E6 = ""
	putexcel H3:H6 = ""
	
	
* end of subgroup table *
	
	
* end of dofile *
