/*******************************************************************************

Title: 			table_s5_health_paper.do
Author(s): 		Caleb Jeremie Dohou
Description: 	This dofile produces table 5: Province subgroup analysis. Table S5. Intervention effects on all primary outcomes, province-by-intervention interaction models. 
Input: 	"${hp_hh_child_roster}", "${hp_anthro_z_constructed}", "${hp_vl_constructed}", see global defined in Project_MasterDofile.do
Output:	"${hp_tables}/table_s5_hp.csv"

*******************************************************************************/	

********************************************************************************
* Province Heterogenous Analysis
********************************************************************************

* Table for Lancet paper
	use "${hp_anthro_z_constructed}", clear // Load Anthro constructed data

label var _zlen "Height for age"


local depvar _zlen
local indepvar treatment_status 

reg `depvar' `indepvar' child_sex child_age_years i.province#cluster_strata, vce(cluster group)

est sto height_for_age_simple

* end of subgroup table *

**** Length for age
	use "${hp_anthro_z_constructed}", clear // Load Anthro constructed data

label var _zlen "Height for age"


local depvar _zlen
local indepvar treatment_status 

reg `depvar' `indepvar' child_sex child_age_years treatment_status##i.province i.province#cluster_strata, vce(cluster group)

est sto height_for_age_interaction



* Conduct Wald test for interaction terms
testparm treatment_status#i.province

* Save F-statistic and p-value as scalars
scalar F_stat = r(F)
scalar p_value = r(p)

* Add F-statistic and p-value to regression output
estadd scalar Wald_F = F_stat
estadd scalar Wald_p = p_value

		

**** WASH institutions index
	use "${hp_vl_constructed}", clear // Load VL constructed data

label var ME_institutions "WASH institutions index"

local depvar ME_institutions
local indepvar treatment_status 

reg `depvar' `indepvar' i.province#cluster_strata, vce(cluster group)

est sto institution_simple


**** WASH institutions index
	use "${hp_vl_constructed}", clear // Load VL constructed data

label var ME_institutions "WASH institutions index"

local depvar ME_institutions
local indepvar treatment_status 

reg `depvar' `indepvar' treatment_status##i.province i.province#cluster_strata, vce(cluster group)

est sto institution_interaction

* Conduct Wald test for interaction terms
testparm treatment_status#i.province

* Save F-statistic and p-value as scalars
scalar F_stat = r(F)
scalar p_value = r(p)

* Add F-statistic and p-value to regression output
estadd scalar Wald_F = F_stat
estadd scalar Wald_p = p_value



******** load child-level dataset
use "${hp_hh_child_roster}", clear

gen ME_institutions = .
label var ME_institutions "WASH institutions index"

gen _zlen = .
label var _zlen "Height for age"

label var diarrhea_outcome "Diarrhea"
label var child_sex "Child's sex"
label var child_age_years "Child's age (years)"
label var treatment_status "Treatment"

local depvar diarrhea_outcome
local indepvar treatment_status 

reg `depvar' `indepvar' child_sex child_age_years i.province#cluster_strata, vce(cluster group)

est sto diarrhea_simple
		

******** load child-level dataset
use "${hp_hh_child_roster}", clear

gen ME_institutions = .
label var ME_institutions "WASH institutions index"

gen _zlen = .
label var _zlen "Height for age"

label var diarrhea_outcome "Diarrhea"
label var child_sex "Child's sex"
label var child_age_years "Child's age (years)"
label var treatment_status "Treatment"

local depvar diarrhea_outcome
local indepvar treatment_status 

reg `depvar' `indepvar' child_sex child_age_years treatment_status##i.province i.province#cluster_strata, vce(cluster group)

est sto diarrhea_interaction

* Conduct Wald test for interaction terms
testparm treatment_status#i.province

* Save F-statistic and p-value as scalars
scalar F_stat = r(F)
scalar p_value = r(p)

* Add F-statistic and p-value to regression output
estadd scalar Wald_F = F_stat
estadd scalar Wald_p = p_value

esttab 	institution_simple institution_interaction diarrhea_simple diarrhea_interaction height_for_age_simple height_for_age_interaction ///
		using "${hp_tables}/table_s5_hp.csv", ///
		replace se label noomitted nobaselevels ///
		star(* .1 ** .05 *** .01) ///
		b(%9.3f) se(%9.3f) ///
		mtitles("WASH Intitutions Index - Simple" "WASH Intitutions Index - Interaction" "Diarrhea - Simple" "Diarrhea - Interaction" "Height for Age - Simple" "Height for Age - Interaction") wrap unstack depvars scalars(Wald_F Wald_p)
		
* end of subgroup table *	

	
* end of dofile *
