/*******************************************************************************

Title: 			table_s6_health_paper.do
Author(s): 		Caleb Jeremide Dohou
Description: 	This dofile produces table s4: Gender subgroup analysis. Table S6. Intervention effects on diarrhea and length-for-age z score, separately by sex (pre-specified)
Input: 	"${hp_hh_child_roster}", "${hp_anthro_z_constructed}", see global defined in Project_MasterDofile.do
Output:	"${hp_tables}/table_s6_hp.xlsx"

*******************************************************************************/	
	
	
************************************************************************************
* Gender Subgroup Analysis
************************************************************************************

******** load child-level dataset
use "${hp_hh_child_roster}", clear

**** Regression, clustered at HH
	
* Diarrhea outcome
global primary diarrhea_outcome

mat results = J(`: word count $primary'*2, 9, .)
forvalues i = 1/`: word count $primary' {
 forvalues j=1/2{
	local var: word `i' of $primary
	reg `var' treatment_status child_age_years i.province#cluster_strata if _child_sex_ ==`j', vce(cluster group)
	matrix row1=r(table) 
	matrix results[(`i'-1)*4+`j',7]=row1[1,1]
	matrix results[(`i'-1)*4+`j',8]=row1[5,1]
	matrix results[(`i'-1)*4+`j',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[(`i'-1)*4+`j',1]=r(N)
	matrix results[(`i'-1)*4+`j',2]=r(mean)
	matrix results[(`i'-1)*4+`j',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[(`i'-1)*4+`j',4]=r(N)
	matrix results[(`i'-1)*4+`j',5]=r(mean)
	matrix results[(`i'-1)*4+`j',6]=r(sd)
	*matrix results[`i',1]="`var'"
	}
}
	matrix list results
	putexcel set "${hp_tables}/table_s6_hp.xlsx", replace
		
	putexcel C3 = matrix(results), nformat(number_d2)
	* add headers
	putexcel A2 = "Outcomes"
	putexcel B2 = "Province"
	putexcel C1 = "Control"
	putexcel C2 = "n"
	putexcel D2 = "Prevalence/Mean"
	putexcel E2 = "SD"
	putexcel (C1:E1), merge hcenter
	putexcel F1 = "Intervention"
	putexcel F2 = "n"
	putexcel G2 = "Prevalence/Mean"
	putexcel H2 = "SD"
	putexcel (E1:G1), merge hcenter
	putexcel I2 = "ITT"
	putexcel J1 = "CI 95%"
	putexcel J2 = "Lower Bound"
	putexcel K2 = "Upper Bound"
	putexcel (J1:K1), merge hcenter
	* add var labels
	putexcel A3 = "Diarrhea prevalence"

	* add gender labels
	putexcel B3 = "Female"
	putexcel B4 = "Male"

	
* end of subgroup table *
	

	
	**** Length for age
	use "${hp_anthro_z_constructed}", clear // Load Anthro constructed data
		
* Primary outcome
global primary _zlen

* table
mat results = J(`: word count $primary'*2, 9, .)
forvalues i = 1/`: word count $primary' {
 forvalues j=1/2{
	local var: word `i' of $primary
	reg `var' treatment_status selected_age_years i.province#cluster_strata if selected_child_sex ==`j', vce(cluster group)
	matrix row1=r(table) 
	matrix results[(`i'-1)*4+`j',7]=row1[1,1]
	matrix results[(`i'-1)*4+`j',8]=row1[5,1]
	matrix results[(`i'-1)*4+`j',9]=row1[6,1]
 sum `var' if e(sample) & treatment_status == 0
	matrix results[(`i'-1)*4+`j',1]=r(N)
	matrix results[(`i'-1)*4+`j',2]=r(mean)
	matrix results[(`i'-1)*4+`j',3]=r(sd)
sum `var' if e(sample) & treatment_status == 1
	matrix results[(`i'-1)*4+`j',4]=r(N)
	matrix results[(`i'-1)*4+`j',5]=r(mean)
	matrix results[(`i'-1)*4+`j',6]=r(sd)
	*matrix results[`i',1]="`var'"
	}
}
	matrix list results
	putexcel set "${hp_tables}/table_s6_hp.xlsx", modify 
	putexcel C6 = matrix(results), nformat(number_d2)
	
	* add var labels
	putexcel A6 = "Length-for-age Z-score"
	
	* add gender labels
	putexcel B6 = "Female"
	putexcel B7 = "Male"
	
	* Final formatting
	putexcel C3:C7, overwritefmt nformat(number)
	putexcel F3:F7, overwritefmt nformat(number)
	
	putexcel D3:D4, overwritefmt nformat(percent)
	putexcel G3:G4, overwritefmt nformat(percent)
	
	* Deleted SDs for binary variables
	putexcel E3:E4 = ""
	putexcel H3:H4 = ""
	

* end of subgroup table *
	
	
* end of dofile *
