/*******************************************************************************

Title: 			05_construct.do
Author(s): 		Luca Stanus Ghib
Description: 	This dofile loads the clean data and constructs variables and indices.
Input: 	"${hp_vl_clean}", see global defined in Project_MasterDofile.do
Output:	"${hp_vl_constructed}", see global defined in Project_MasterDofile.do

*******************************************************************************/

******** load raw dataset
use "${hp_vl_clean}", clear

**** Add treatment status & cluster info to dataset so that it can be used for analysis
merge m:1 village using "${hp_village_list}", keepusing(treatment_status group cluster_strata) // 3 villages not matched from using? CHECK WHY
drop if _merge==2

// Presence of committee (yes to G1 or G2)
* n: codebook wash_committee_check water_committee
gen wa_comm = .
replace wa_comm=1 if wash_committee_check==1
replace wa_comm=0 if wash_committee_check==0
replace wa_comm=1 if water_committee==1

// How often meet? wash_comm_meetings is 1 = weekly to 6 = no regular schedule, if we want to have highest value = "best" maintenance practice then we need to reverse the value order (bear in mind 136/328 missing) 
* n: codebook wash_comm_meetings
gen wash_comm_meetings_r = wash_comm_meetings
recode wash_comm_meetings 1=6 2=5 3=4 4=3 5=2 6=1


// Comm spending? wash_exp_water would be the only value we could winsorize (monetary amt, capped at 200k by us through constraints). Only missing for villages without a committee
* n: codebook wash_exp_water
* hist wash_exp_water // highly right skewed
gen wash_exp_water_log = log(wash_exp_water)
* hist wash_exp_water_log // more or less normal
* use inverse hyperbolic sine bc many zeroes and skewed
gen wash_exp_water_ihs = asinh(wash_exp_water)


*** Index construction (requires treatment_status var)
g WEIGHT=1

WMEANEFFECTS treatment_status WEIGHT wa_comm wash_comm_meetings_r wash_exp_water_ihs health_track defec_track if treatment_status!=., g(ME_institutions)
*comm_mantain_plan removed because missing in treatment group

label var ME_institutions "WASH institutionds index"

******** replace constructed dataset to include treatment/cluster info
save "${hp_vl_constructed}", replace

* end of dofile *
